@@ -34,14 +34,10 @@
 #include <limits.h>
 #include <stdlib.h>
 
-#include <blockdev/blockdev.h>
-
 #include "udisksdaemon.h"
 #include "udisksdaemonutil.h"
 #include "udisksstate.h"
 #include "udiskslogging.h"
-#include "udiskslinuxdevice.h"
-#include "udiskslinuxprovider.h"
 #include "udiskslinuxblockobject.h"
 #include "udiskslinuxdriveobject.h"
 
@@ -86,41 +82,6 @@ GString* udisks_string_concat (GString *a,
   return result;
 }
 
-gchar *
-udisks_daemon_util_subst_str (const gchar *str,
-           const gchar *from,
-           const gchar *to)
-{
-    gchar **parts;
-    gchar *result;
-
-    parts = g_strsplit (str, from, 0);
-    result = g_strjoinv (to, parts);
-    g_strfreev (parts);
-    return result;
-}
-
-/**
- * udisks_daemon_util_subst_str_and_escape:
- * @str: A command string with variables to replace.
- * @from: A variable name that should be expanded.
- * @to: The value for that variable. Will be escaped for shells before
- * substitution.
- *
- * Returns: The command string with the substituted variable.
- */
-gchar *
-udisks_daemon_util_subst_str_and_escape (const gchar *str,
-                      const gchar *from,
-                      const gchar *to)
-{
-  gchar *quoted_and_escaped;
-  gchar *ret;
-  quoted_and_escaped = g_shell_quote (to);
-  ret = udisks_daemon_util_subst_str (str, from, quoted_and_escaped);
-  g_free (quoted_and_escaped);
-  return ret;
-}
 
 /**
  * udisks_string_wipe_and_free:
@@ -159,13 +120,7 @@ udisks_variant_lookup_binary (GVariant     *dict,
 {
   GVariant* item = g_variant_lookup_value (dict, name, NULL);
   if (item)
-    {
-      gboolean ret = udisks_variant_get_binary (item, out_text);
-      g_variant_unref (item);
-
-      return ret;
-    }
-
+    return udisks_variant_get_binary (item, out_text);
   return FALSE;
 }
 
@@ -209,7 +164,6 @@ udisks_variant_get_binary (GVariant  *value,
 /**
  * udisks_decode_udev_string:
  * @str: An udev-encoded string or %NULL.
- * @fallback_str: String to use when @str can't be converted to a valid UTF-8 string.
  *
  * Unescapes sequences like \x20 to " " and ensures the returned string is valid UTF-8.
  *
@@ -223,7 +177,7 @@ udisks_variant_get_binary (GVariant  *value,
  * Returns: A valid UTF-8 string that must be freed with g_free().
  */
 gchar *
-udisks_decode_udev_string (const gchar *str, const gchar *fallback_str)
+udisks_decode_udev_string (const gchar *str)
 {
   GString *s;
   gchar *ret;
@@ -264,17 +218,8 @@ udisks_decode_udev_string (const gchar *str, const gchar *fallback_str)
   if (!g_utf8_validate (s->str, -1, &end_valid))
     {
       udisks_warning ("The string `%s' is not valid UTF-8. Invalid characters begins at `%s'", s->str, end_valid);
-      if (fallback_str)
-        {
-          udisks_info ("Invalid string `%s' replaced by `%s'", s->str, fallback_str);
-          ret = g_strdup (fallback_str);
-          g_string_free (s, TRUE);
-        }
-      else
-        {
-          ret = g_strndup (s->str, end_valid - s->str);
-          g_string_free (s, TRUE);
-        }
+      ret = g_strndup (s->str, end_valid - s->str);
+      g_string_free (s, TRUE);
     }
   else
     {
@@ -322,41 +267,6 @@ udisks_safe_append_to_object_path (GString      *str,
     }
 }
 
-/**
- * udisks_g_object_ref_foreach:
- * @object: A #GObject to ref.
- * @unused: Unused parameter.
- *
- * This is a helper function for g_list_foreach. It expects a function
- * that takes two parameters but the standard g_object_ref takes just one
- * and using it makes gcc sad. So this function just calls g_object_ref
- * and throws away the second parameter.
- */
-void
-udisks_g_object_ref_foreach (gpointer object, gpointer unused)
-{
-  g_return_if_fail (G_IS_OBJECT (object));
-  g_object_ref (G_OBJECT (object));
-  return;
-}
-
-/**
- * udisks_g_object_ref_copy:
- * @object: A #GObject to ref.
- * @unused: Unused parameter.
- *
- * This is a helper function for g_list_copy_deep. It expects copy function
- * that takes two parameters but the standard g_object_ref takes just one
- * and using it makes gcc sad. So this function just calls g_object_ref
- * and throws away the second parameter.
- */
-void *
-udisks_g_object_ref_copy (gconstpointer object, gpointer unused)
-{
-  g_return_val_if_fail (G_IS_OBJECT (object), NULL);
-  return g_object_ref (G_OBJECT (object));
-}
-
 /**
  * udisks_daemon_util_block_get_size:
  * @device: A #GUdevDevice for a top-level block device.
@@ -583,9 +493,9 @@ udisks_daemon_util_setup_by_user (UDisksDaemon *daemon,
     {
       UDisksBlock *crypto_block;
       crypto_block = udisks_object_peek_block (crypto_object);
-      if (udisks_state_find_unlocked_crypto_dev (state,
-                                                 udisks_block_get_device_number (crypto_block),
-                                                 &setup_by_user))
+      if (udisks_state_find_unlocked_luks (state,
+                                           udisks_block_get_device_number (crypto_block),
+                                           &setup_by_user))
         {
           if (setup_by_user == user)
             {
@@ -661,6 +571,8 @@ check_authorization_no_polkit (UDisksDaemon            *daemon,
                                                invocation,
                                                NULL,         /* GCancellable* */
                                                &caller_uid,
+                                               NULL,         /* gid_t *out_gid */
+                                               NULL,         /* gchar **out_user_name */
                                                &sub_error))
     {
       g_set_error (error,
@@ -1029,56 +941,6 @@ out:
   return ret;
 }
 
-/**
- * udisks_daemon_util_get_user_info:
- * @out_gid: (out) (allow-none): Return location for resolved gid or %NULL.
- * @out_user_name: (out) (allow-none): Return location for resolved user name or %NULL.
- * @error: Return location for error.
- *
- * Gets the UNIX group and user name for a user id.
- *
- * Returns: %TRUE if the user information was obtained, %FALSE otherwise
- */
-gboolean
-udisks_daemon_util_get_user_info (const uid_t uid,
-                                  gid_t *out_gid,
-                                  gchar **out_user_name,
-                                  GError     **error)
-{
-  struct passwd pwstruct;
-  gchar pwbuf[8192];
-  struct passwd *pw = NULL;
-  int rc;
-
-  rc = getpwuid_r (uid, &pwstruct, pwbuf, sizeof pwbuf, &pw);
-  if (rc == 0 && pw == NULL)
-    {
-      g_set_error (error,
-                   UDISKS_ERROR,
-                   UDISKS_ERROR_FAILED,
-                   "User with uid %d does not exist", (gint) uid);
-      goto out;
-    }
-  else if (pw == NULL)
-    {
-      g_set_error (error,
-                   UDISKS_ERROR,
-                   UDISKS_ERROR_FAILED,
-                   "Error looking up passwd struct for uid %d: %m", (gint) uid);
-      goto out;
-    }
-
-  if (out_gid != NULL)
-    *out_gid = pw->pw_gid;
-
-  if (out_user_name != NULL)
-      *out_user_name = g_strdup (pwstruct.pw_name);
-
-  return TRUE;
-
-out:
-  return FALSE;
-}
 
 /**
  * udisks_daemon_util_get_caller_uid_sync:
@@ -1086,9 +948,12 @@ out:
  * @invocation: A #GDBusMethodInvocation.
  * @cancellable: (allow-none): A #GCancellable or %NULL.
  * @out_uid: (out): Return location for resolved uid or %NULL.
+ * @out_gid: (out) (allow-none): Return location for resolved gid or %NULL.
+ * @out_user_name: (out) (allow-none): Return location for resolved user name or %NULL.
  * @error: Return location for error.
  *
- * Gets the UNIX user id of the peer represented by @invocation.
+ * Gets the UNIX user id (and possibly group id and user name) of the
+ * peer represented by @invocation.
  *
  * Returns: %TRUE if the user id (and possibly group id) was obtained, %FALSE otherwise
  */
@@ -1097,6 +962,8 @@ udisks_daemon_util_get_caller_uid_sync (UDisksDaemon            *daemon,
                                         GDBusMethodInvocation   *invocation,
                                         GCancellable            *cancellable,
                                         uid_t                   *out_uid,
+                                        gid_t                   *out_gid,
+                                        gchar                  **out_user_name,
                                         GError                 **error)
 {
   gboolean ret;
@@ -1116,6 +983,36 @@ udisks_daemon_util_get_caller_uid_sync (UDisksDaemon            *daemon,
   if (out_uid != NULL)
     *out_uid = uid;
 
+  if (out_gid != NULL || out_user_name != NULL)
+    {
+      struct passwd pwstruct;
+      gchar pwbuf[8192];
+      struct passwd *pw = NULL;
+      int rc;
+
+      rc = getpwuid_r (uid, &pwstruct, pwbuf, sizeof pwbuf, &pw);
+      if (rc == 0 && pw == NULL)
+        {
+          g_set_error (error,
+                       UDISKS_ERROR,
+                       UDISKS_ERROR_FAILED,
+                       "User with uid %d does not exist", (gint) uid);
+          goto out;
+        }
+      else if (pw == NULL)
+        {
+          g_set_error (error,
+                       UDISKS_ERROR,
+                       UDISKS_ERROR_FAILED,
+                       "Error looking up passwd struct for uid %d: %m", (gint) uid);
+          goto out;
+        }
+      if (out_gid != NULL)
+        *out_gid = pw->pw_gid;
+      if (out_user_name != NULL)
+        *out_user_name = g_strdup (pwstruct.pw_name);
+    }
+
   ret = TRUE;
 
  out:
@@ -1143,7 +1040,7 @@ udisks_daemon_util_get_caller_pid_sync (UDisksDaemon            *daemon,
                                         pid_t                   *out_pid,
                                         GError                 **error)
 {
-  /* "GetConnectionUnixProcessID" */
+  // "GetConnectionUnixProcessID"
 
   /* TODO: cache this on @daemon */
   /* NOTE: pid_t is a signed 32 bit, but the
@@ -1188,6 +1085,75 @@ udisks_daemon_util_dup_object (gpointer   interface_,
   return ret;
 }
 
+static void
+escaper (GString *s, const gchar *str)
+{
+  const gchar *p;
+  for (p = str; *p != '\0'; p++)
+    {
+      gint c = *p;
+      switch (c)
+        {
+        case '"':
+          g_string_append (s, "\\\"");
+          break;
+
+        case '\\':
+          g_string_append (s, "\\\\");
+          break;
+
+        default:
+          g_string_append_c (s, c);
+          break;
+        }
+    }
+}
+
+/**
+ * udisks_daemon_util_escape_and_quote:
+ * @str: The string to escape.
+ *
+ * Like udisks_daemon_util_escape() but also wraps the result in
+ * double-quotes.
+ *
+ * Returns: The double-quoted and escaped string. Free with g_free().
+ */
+gchar *
+udisks_daemon_util_escape_and_quote (const gchar *str)
+{
+  GString *s;
+
+  g_return_val_if_fail (str != NULL, NULL);
+
+  s = g_string_new ("\"");
+  escaper (s, str);
+  g_string_append_c (s, '"');
+
+  return g_string_free (s, FALSE);
+}
+
+/**
+ * udisks_daemon_util_escape:
+ * @str: The string to escape.
+ *
+ * Escapes double-quotes (&quot;) and back-slashes (\) in a string
+ * using back-slash (\).
+ *
+ * Returns: The escaped string. Free with g_free().
+ */
+gchar *
+udisks_daemon_util_escape (const gchar *str)
+{
+  GString *s;
+
+  g_return_val_if_fail (str != NULL, NULL);
+
+  s = g_string_new (NULL);
+  escaper (s, str);
+
+  return g_string_free (s, FALSE);
+}
+
 /**
  * udisks_daemon_util_on_user_seat:
  * @daemon: A #UDisksDaemon.
@@ -1560,7 +1526,7 @@ udisks_daemon_util_uninhibit_system_sync (UDisksInhibitCookie *cookie)
       g_assert (cookie->magic == 0xdeadbeef);
       if (close (cookie->fd) != 0)
         {
-          udisks_critical ("Error closing inhibit-fd: %m");
+          udisks_critical ("Error closing inhbit-fd: %m");
         }
       g_free (cookie);
     }
@@ -1630,279 +1596,3 @@ udisks_ata_identify_get_word (const guchar *identify_data, guint word_number)
  out:
   return ret;
 }
-
-
-/* ---------------------------------------------------------------------------------------------------- */
-
-static volatile guint uevent_serial = 0;
-
-static gboolean
-trigger_uevent (const gchar *path, const gchar *str)
-{
-  gint fd;
-
-  fd = open (path, O_WRONLY);
-  if (fd < 0)
-    {
-      udisks_warning ("Error opening %s while triggering uevent: %m", path);
-      return FALSE;
-    }
-
-  if (write (fd, str, strlen (str)) != (ssize_t) strlen (str))
-    {
-      udisks_warning ("Error writing '%s' to file %s: %m", str, path);
-      close (fd);
-      return FALSE;
-    }
-
-  close (fd);
-  return TRUE;
-}
-
-typedef struct
-{
-  UDisksDaemon *daemon;
-  GMainLoop *main_loop;
-  guint serial;
-  gchar *uevent_path;
-  gboolean success;
-} SynthUeventData;
-
-static gboolean
-trigger_uevent_idle_cb (gpointer user_data)
-{
-  SynthUeventData *data = user_data;
-  gchar *str;
-
-  str = g_strdup_printf ("change %s UDISKSSERIAL=%u", udisks_daemon_get_uuid (data->daemon), data->serial);
-
-  if (! trigger_uevent (data->uevent_path, str))
-    {
-      /* kernel refused our string, try simple "change" but don't wait for it */
-      trigger_uevent (data->uevent_path, "change");
-      data->success = FALSE;
-      g_main_loop_quit (data->main_loop);
-    }
-  g_free (str);
-
-  /* remove the source */
-  return FALSE;
-}
-
-static gboolean
-uevent_wait_timeout_cb (gpointer user_data)
-{
-  SynthUeventData *data = user_data;
-
-  data->success = FALSE;
-  g_main_loop_quit (data->main_loop);
-
-  /* remove the source */
-  return FALSE;
-}
-
-static void
-uevent_probed_cb (UDisksLinuxProvider *provider,
-                  const gchar         *action,
-                  UDisksLinuxDevice   *device,
-                  gpointer             user_data)
-{
-  SynthUeventData *data = user_data;
-  const gchar *received_serial_str;
-  gint64 received_serial;
-  gchar *endptr;
-
-  received_serial_str = g_udev_device_get_property (device->udev_device, "SYNTH_ARG_UDISKSSERIAL");
-  if (received_serial_str != NULL)
-    {
-      endptr = (gchar *) received_serial_str;
-      received_serial = g_ascii_strtoll (received_serial_str, &endptr, 0);
-      if (endptr != received_serial_str && received_serial == data->serial)
-        {
-          data->success = TRUE;
-          g_main_loop_quit (data->main_loop);
-        }
-    }
-}
-
-static gchar *
-resolve_uevent_path (UDisksDaemon *daemon,
-                     const gchar  *device_file,
-                     const gchar  *sysfs_path)
-{
-  GUdevClient *gudev_client;
-  GUdevDevice *gudev_device;
-  gchar *path = NULL;
-  gchar *basename;
-
-  if (sysfs_path != NULL)
-    return g_build_filename (sysfs_path, "uevent", NULL);
-
-  /* try querying the udev database */
-  gudev_client = udisks_linux_provider_get_udev_client (udisks_daemon_get_linux_provider (daemon));
-  /* gudev calls stat() on the device_file, effectively resolving symlinks */
-  gudev_device = g_udev_client_query_by_device_file (gudev_client, device_file);
-  if (gudev_device != NULL)
-    {
-      path = g_build_filename (g_udev_device_get_sysfs_path (gudev_device), "uevent", NULL);
-      g_object_unref (gudev_device);
-    }
-
-  if (path != NULL)
-    return path;
-
-  /* construct the path manually, assuming no entries in /dev */
-  basename = g_path_get_basename (device_file);
-  path = g_build_filename ("/sys/block", basename, "uevent", NULL);
-  g_free (basename);
-
-  return path;
-}
-
-/**
- * udisks_daemon_util_trigger_uevent:
- * @daemon: A #UDisksDaemon.
- * @device_file: Block device file (/dev/xxx) or %NULL.
- * @sysfs_path: Device path in /sys or %NULL.
- *
- * Triggers a 'change' uevent in the kernel.
- *
- * The @sysfs_path takes precedence if non-NULL over a @device_file.
- * In case of using @device_file any symlinks are resolved, this expects
- * the block device has been processed by udev already.
- *
- * The triggered event will bubble up from the kernel through the udev
- * stack and will eventually be received by the udisks daemon process
- * itself. This method does not wait for the event to be received.
- */
-void
-udisks_daemon_util_trigger_uevent (UDisksDaemon *daemon,
-                                   const gchar  *device_file,
-                                   const gchar  *sysfs_path)
-{
-  gchar *path;
-
-  g_return_if_fail (UDISKS_IS_DAEMON (daemon));
-  g_return_if_fail (device_file != NULL || sysfs_path != NULL);
-
-  path = resolve_uevent_path (daemon, device_file, sysfs_path);
-  trigger_uevent (path, "change");
-  g_free (path);
-}
-
-/**
- * udisks_daemon_util_trigger_uevent_sync:
- * @daemon: A #UDisksDaemon.
- * @device_file: Block device file (/dev/xxx) or %NULL.
- * @sysfs_path: Device path in /sys or %NULL.
- * @timeout_seconds: Maximum time to wait for the uevent (in seconds).
- *
- * Triggers a 'change' uevent in the kernel and waits until it's received and
- * processed by udisks.
- *
- * The @sysfs_path takes precedence if non-NULL over a @device_file.
- * In case of using @device_file any symlinks are resolved, this expects
- * the block device has been processed by udev already.
- *
- * Unlike udisks_daemon_util_trigger_uevent() that just triggers
- * a synthetic uevent to the kernel, this call will actually block and wait until
- * the #UDisksLinuxProvider receives the uevent, performs probing and processes
- * the uevent further down the UDisks object stack. Upon returning from this
- * function call the caller may assume the event has been fully processed, all
- * D-Bus objects are updated and settled. Typically used in busy wait for
- * a particular D-Bus interface.
- *
- * Note that this uses synthetic uevent tagging and only works on linux kernel
- * 4.13 and higher. In case an older kernel is detected this acts like the classic
- * udisks_daemon_util_trigger_uevent() call and %FALSE is returned.
- *
- * Returns: %TRUE if the uevent has been successfully received, %FALSE otherwise
- * or when the kernel version is too old.
- */
-gboolean
-udisks_daemon_util_trigger_uevent_sync (UDisksDaemon *daemon,
-                                        const gchar  *device_file,
-                                        const gchar  *sysfs_path,
-                                        guint         timeout_seconds)
-{
-  UDisksLinuxProvider *provider;
-  SynthUeventData data;
-  GMainContext *main_context;
-  GSource *idle_source;
-  GSource *timeout_source;
-
-  g_return_val_if_fail (UDISKS_IS_DAEMON (daemon), FALSE);
-  g_return_val_if_fail (device_file != NULL || sysfs_path != NULL, FALSE);
-
-  if (bd_utils_check_linux_version (4, 13, 0) < 0)
-    {
-      udisks_daemon_util_trigger_uevent (daemon, device_file, sysfs_path);
-      return FALSE;
-    }
-
-  data.daemon = daemon;
-  data.uevent_path = resolve_uevent_path (daemon, device_file, sysfs_path);
-  if (data.uevent_path == NULL)
-    return FALSE;
-  data.serial = g_atomic_int_add (&uevent_serial, 1);
-
-  main_context = g_main_context_new ();
-  g_main_context_push_thread_default (main_context);
-  data.main_loop = g_main_loop_new (main_context, FALSE);
-
-  /* queue the actual trigger in the loop */
-  idle_source = g_idle_source_new ();
-  g_source_set_callback (idle_source, (GSourceFunc) trigger_uevent_idle_cb, &data, NULL);
-  g_source_attach (idle_source, main_context);
-  g_source_unref (idle_source);
-
-  /* add timeout as a fallback */
-  timeout_source = g_timeout_source_new_seconds (timeout_seconds);
-  g_source_set_callback (timeout_source, (GSourceFunc) uevent_wait_timeout_cb, &data, NULL);
-  g_source_attach (timeout_source, main_context);
-  g_source_unref (timeout_source);
-
-  /* catch incoming uevents */
-  provider = udisks_daemon_get_linux_provider (daemon);
-  g_signal_connect (provider, "uevent-probed", G_CALLBACK (uevent_probed_cb), &data);
-
-  data.success = FALSE;
-  g_main_loop_run (data.main_loop);
-
-  g_signal_handlers_disconnect_by_func (provider, uevent_probed_cb, &data);
-  g_main_context_pop_thread_default (main_context);
-
-  g_main_loop_unref (data.main_loop);
-  g_main_context_unref (main_context);
-  g_free (data.uevent_path);
-
-  return data.success;
-}
-
-/* ---------------------------------------------------------------------------------------------------- */
-
-/**
- * udisks_module_validate_name:
- * @module_name: A udisks2 module name.
- *
- * Checks the string for a valid udisks2 module name. Only alphanumeric characters
- * along with the '-' and '_' separators are permitted.
- *
- * Returns: %TRUE if the string is a valid udisks2 module name, %FALSE otherwise.
- */
-gboolean
-udisks_module_validate_name (const gchar *module_name)
-{
-  int i;
-
-  for (i = 0; module_name[i] != '\0'; i++)
-    /* going ASCII, will disqualify any UTF-* string */
-    if (! g_ascii_isalnum (module_name[i]) &&
-        module_name[i] != '-' &&
-        module_name[i] != '_')
-      return FALSE;
-
-  return TRUE;
-}
-
-/* ---------------------------------------------------------------------------------------------------- */
