@@ -122,8 +122,8 @@ udisks_linux_loop_update (UDisksLinuxLoop        *loop,
   UDisksState *state;
   UDisksLinuxDevice *device;
   uid_t setup_by_uid;
+  gchar *backing_file;
   GError *error = NULL;
-  BDLoopInfo *info = NULL;
 
   daemon = udisks_linux_block_object_get_daemon (UDISKS_LINUX_BLOCK_OBJECT (object));
   state = udisks_daemon_get_state (daemon);
@@ -131,42 +131,53 @@ udisks_linux_loop_update (UDisksLinuxLoop        *loop,
 
   if (g_str_has_prefix (g_udev_device_get_name (device->udev_device), "loop"))
     {
-      info = bd_loop_info (g_udev_device_get_name (device->udev_device), &error);
+      backing_file = bd_loop_get_backing_file (g_udev_device_get_name (device->udev_device),
+                                               &error);
 
-      if (info == NULL)
+      if (backing_file == NULL)
         {
           if (error != NULL)
             {
-              if (! g_error_matches (error, BD_LOOP_ERROR, BD_LOOP_ERROR_DEVICE))
-                {
-                  udisks_warning ("Error getting '%s' information: %s (%s, %d)",
-                                  g_udev_device_get_name (device->udev_device),
-                                  error->message,
-                                  g_quark_to_string (error->domain),
-                                  error->code);
-                }
+              udisks_warning ("Error getting '%s' backing file: %s (%s, %d)",
+                              g_udev_device_get_name (device->udev_device),
+                              error->message,
+                              g_quark_to_string (error->domain),
+                              error->code);
               g_clear_error (&error);
             }
           udisks_loop_set_backing_file (UDISKS_LOOP (loop), "");
-          udisks_loop_set_autoclear (UDISKS_LOOP (loop), FALSE);
         }
       else
         {
-          if (info->backing_file == NULL)
-              udisks_loop_set_backing_file (UDISKS_LOOP (loop), "");
-          else
-              udisks_loop_set_backing_file (UDISKS_LOOP (loop), info->backing_file);
-
-          udisks_loop_set_autoclear (UDISKS_LOOP (loop), info->autoclear);
+          udisks_loop_set_backing_file (UDISKS_LOOP (loop), backing_file);
         }
-
-      bd_loop_info_free (info);
     }
   else
     {
       udisks_loop_set_backing_file (UDISKS_LOOP (loop), "");
     }
 
+  if (backing_file == NULL)
+    {
+      udisks_loop_set_autoclear (UDISKS_LOOP (loop), FALSE);
+    }
+  else
+    {
+      udisks_loop_set_autoclear (UDISKS_LOOP (loop),
+                                 bd_loop_get_autoclear (g_udev_device_get_name (device->udev_device),
+                                                        &error));
+      g_free (backing_file);
+      if (error != NULL)
+        {
+          udisks_warning ("Error getting '%s' autoclear: %s (%s, %d)",
+                          g_udev_device_get_name (device->udev_device),
+                          error->message,
+                          g_quark_to_string (error->domain),
+                          error->code);
+          g_clear_error (&error);
+        }
+    }
+
   setup_by_uid = 0;
   if (state != NULL)
     {
@@ -176,7 +187,6 @@ udisks_linux_loop_update (UDisksLinuxLoop        *loop,
     }
   udisks_loop_set_setup_by_uid (UDISKS_LOOP (loop), setup_by_uid);
 
-  g_dbus_interface_skeleton_flush (G_DBUS_INTERFACE_SKELETON (loop));
   g_object_unref (device);
 }
 
@@ -191,7 +201,7 @@ handle_delete (UDisksLoop            *loop,
   UDisksObject *object = NULL;
   UDisksBlock *block;
   UDisksDaemon *daemon = NULL;
-  UDisksState *state = NULL;
+  UDisksState *state;
   GError *error = NULL;
   uid_t caller_uid;
   uid_t setup_by_uid;
@@ -209,11 +219,8 @@ handle_delete (UDisksLoop            *loop,
   daemon = udisks_linux_block_object_get_daemon (UDISKS_LINUX_BLOCK_OBJECT (object));
   state = udisks_daemon_get_state (daemon);
 
-  udisks_linux_block_object_lock_for_cleanup (UDISKS_LINUX_BLOCK_OBJECT (object));
-  udisks_state_check_block (state, udisks_linux_block_object_get_device_number (UDISKS_LINUX_BLOCK_OBJECT (object)));
-
   error = NULL;
-  if (!udisks_daemon_util_get_caller_uid_sync (daemon, invocation, NULL, &caller_uid, &error))
+  if (!udisks_daemon_util_get_caller_uid_sync (daemon, invocation, NULL, &caller_uid, NULL, NULL, &error))
     {
       g_dbus_method_invocation_return_gerror (invocation, error);
       g_clear_error (&error);
@@ -249,7 +256,6 @@ handle_delete (UDisksLoop            *loop,
                                          UDISKS_OBJECT(object),
                                          "loop-setup",
                                          caller_uid,
-                                         FALSE,
                                          NULL);
 
   if (job == NULL)
@@ -263,9 +269,9 @@ handle_delete (UDisksLoop            *loop,
 
   if (!bd_loop_teardown (device_file, &error))
     {
-      g_prefix_error (&error, "Error deleting '%s': ", device_file);
-      udisks_simple_job_complete (UDISKS_SIMPLE_JOB (job), FALSE, error->message);
+      g_prefix_error (&error, "Error deleting %s: ", device_file);
       g_dbus_method_invocation_take_error (invocation, error);
+      udisks_simple_job_complete (UDISKS_SIMPLE_JOB (job), FALSE, error->message);
       goto out;
     }
 
@@ -278,10 +284,6 @@ handle_delete (UDisksLoop            *loop,
   udisks_loop_complete_delete (loop, invocation);
 
  out:
-  if (object != NULL)
-    udisks_linux_block_object_release_cleanup_lock (UDISKS_LINUX_BLOCK_OBJECT (object));
-  if (state != NULL)
-    udisks_state_check (state);
   g_free (device_file);
   g_clear_object (&object);
 
@@ -314,7 +316,7 @@ handle_set_autoclear (UDisksLoop             *loop,
   daemon = udisks_linux_block_object_get_daemon (UDISKS_LINUX_BLOCK_OBJECT (object));
 
   error = NULL;
-  if (!udisks_daemon_util_get_caller_uid_sync (daemon, invocation, NULL, &caller_uid, &error))
+  if (!udisks_daemon_util_get_caller_uid_sync (daemon, invocation, NULL, &caller_uid, NULL, NULL, &error))
     {
       g_dbus_method_invocation_return_gerror (invocation, error);
       g_clear_error (&error);
@@ -353,8 +355,9 @@ handle_set_autoclear (UDisksLoop             *loop,
   g_dbus_interface_skeleton_flush (G_DBUS_INTERFACE_SKELETON (loop));
 
   /* ... but make sure we update the property value from sysfs */
-  udisks_linux_block_object_trigger_uevent_sync (UDISKS_LINUX_BLOCK_OBJECT (object),
-                                                 UDISKS_DEFAULT_WAIT_TIMEOUT);
+  udisks_linux_block_object_trigger_uevent (UDISKS_LINUX_BLOCK_OBJECT (object));
+
+  /* TODO: would be better to have something like trigger_uevent_and_wait_for_it_sync() */
 
   udisks_loop_complete_set_autoclear (loop, invocation);
 
