@@ -43,11 +43,10 @@
 #include "udisksdaemonutil.h"
 #include "udisksstate.h"
 #include "udiskslinuxblockobject.h"
-#include "udiskslinuxblock.h"
 #include "udiskslinuxdevice.h"
 #include "udisksmodulemanager.h"
+#include "udiskslinuxfsinfo.h"
 #include "udiskssimplejob.h"
-#include "udisksconfigmanager.h"
 
 /**
  * SECTION:udiskslinuxmanager
@@ -70,6 +69,8 @@ struct _UDisksLinuxManager
 {
   UDisksManagerSkeleton parent_instance;
 
+  GMutex lock;
+
   UDisksDaemon *daemon;
 };
 
@@ -94,6 +95,10 @@ G_DEFINE_TYPE_WITH_CODE (UDisksLinuxManager, udisks_linux_manager, UDISKS_TYPE_M
 static void
 udisks_linux_manager_finalize (GObject *object)
 {
+  UDisksLinuxManager *manager = UDISKS_LINUX_MANAGER (object);
+
+  g_mutex_clear (&(manager->lock));
+
   G_OBJECT_CLASS (udisks_linux_manager_parent_class)->finalize (object);
 }
 
@@ -139,56 +144,15 @@ udisks_linux_manager_set_property (GObject      *object,
     }
 }
 
-static void
-set_supported_filesystems (UDisksLinuxManager *manager)
-{
-  const gchar **fss;
-  const gchar **fss_i;
-  GPtrArray *ptr_array;
-  GError *error = NULL;
-
-  fss = bd_fs_supported_filesystems (&error);
-  if (!fss)
-    {
-      udisks_warning ("Unable to retrieve list of supported filesystems: %s", error->message);
-      g_error_free (error);
-      return;
-    }
-
-  ptr_array = g_ptr_array_new ();
-  for (fss_i = fss; *fss_i; fss_i++)
-    g_ptr_array_add (ptr_array, (gpointer) *fss_i);
-  g_free (fss);
-
-  if (! g_ptr_array_find_with_equal_func (ptr_array, "swap", g_str_equal, NULL))
-    g_ptr_array_add (ptr_array, (gpointer) "swap");
-  g_ptr_array_add (ptr_array, NULL);
-
-  udisks_manager_set_supported_filesystems (UDISKS_MANAGER (manager), (const gchar * const *) ptr_array->pdata);
-  g_ptr_array_free (ptr_array, TRUE);
-}
-
 static void
 udisks_linux_manager_init (UDisksLinuxManager *manager)
 {
+  g_mutex_init (&(manager->lock));
   g_dbus_interface_skeleton_set_flags (G_DBUS_INTERFACE_SKELETON (manager),
                                        G_DBUS_INTERFACE_SKELETON_FLAGS_HANDLE_METHOD_INVOCATIONS_IN_THREAD);
 
-  set_supported_filesystems (manager);
-}
-
-static void
-udisks_linux_manager_constructed (GObject *obj)
-{
-  UDisksLinuxManager *manager = UDISKS_LINUX_MANAGER (obj);
-  UDisksConfigManager *config_manager = udisks_daemon_get_config_manager (manager->daemon);
-
-  udisks_manager_set_default_encryption_type (UDISKS_MANAGER (manager),
-                                              udisks_config_manager_get_encryption (config_manager));
-  udisks_manager_set_supported_encryption_types (UDISKS_MANAGER (manager),
-                                                 udisks_config_manager_get_supported_encryption_types (config_manager));
-
-  G_OBJECT_CLASS (udisks_linux_manager_parent_class)->constructed (obj);
+  udisks_manager_set_supported_filesystems (UDISKS_MANAGER (manager),
+                                            get_supported_filesystems ());
 }
 
 static void
@@ -197,7 +161,6 @@ udisks_linux_manager_class_init (UDisksLinuxManagerClass *klass)
   GObjectClass *gobject_class;
 
   gobject_class = G_OBJECT_CLASS (klass);
-  gobject_class->constructed  = udisks_linux_manager_constructed;
   gobject_class->finalize     = udisks_linux_manager_finalize;
   gobject_class->set_property = udisks_linux_manager_set_property;
   gobject_class->get_property = udisks_linux_manager_get_property;
@@ -353,15 +316,12 @@ handle_loop_setup (UDisksManager          *object,
   gboolean option_no_part_scan = FALSE;
   guint64 option_offset = 0;
   guint64 option_size = 0;
-  guint64 option_sector_size = 0;
   uid_t caller_uid;
-  struct stat fd_statbuf;
-  gboolean fd_statbuf_valid = FALSE;
   WaitForLoopData wait_data;
 
   /* we need the uid of the caller for the loop file */
   error = NULL;
-  if (!udisks_daemon_util_get_caller_uid_sync (manager->daemon, invocation, NULL /* GCancellable */, &caller_uid, &error))
+  if (!udisks_daemon_util_get_caller_uid_sync (manager->daemon, invocation, NULL /* GCancellable */, &caller_uid, NULL, NULL, &error))
     {
       g_dbus_method_invocation_return_gerror (invocation, error);
       g_clear_error (&error);
@@ -381,7 +341,7 @@ handle_loop_setup (UDisksManager          *object,
     goto out;
 
   fd_num = g_variant_get_handle (fd_index);
-  if (fd_list == NULL || fd_num < 0 || fd_num >= g_unix_fd_list_get_length (fd_list))
+  if (fd_list == NULL || fd_num >= g_unix_fd_list_get_length (fd_list))
     {
       g_dbus_method_invocation_return_error (invocation,
                                              UDISKS_ERROR,
@@ -407,7 +367,7 @@ handle_loop_setup (UDisksManager          *object,
       g_dbus_method_invocation_return_error (invocation,
                                              UDISKS_ERROR,
                                              UDISKS_ERROR_FAILED,
-                                             "Error determining path: %m");
+                                             "Error determing path: %m");
       goto out;
     }
   path[path_len] = '\0';
@@ -416,13 +376,6 @@ handle_loop_setup (UDisksManager          *object,
   g_variant_lookup (options, "offset", "t", &option_offset);
   g_variant_lookup (options, "size", "t", &option_size);
   g_variant_lookup (options, "no-part-scan", "b", &option_no_part_scan);
-  g_variant_lookup (options, "sector-size", "t", &option_sector_size);
-
-  /* it's not a problem if fstat fails... for example, this can happen if the user
-   * passes a fd to a file on the GVfs fuse mount
-   */
-  if (fstat (fd, &fd_statbuf) == 0)
-    fd_statbuf_valid = TRUE;
 
   error = NULL;
   if (!bd_loop_setup_from_fd (fd,
@@ -430,7 +383,6 @@ handle_loop_setup (UDisksManager          *object,
                               option_size,
                               option_read_only,
                               !option_no_part_scan,
-                              option_sector_size,
                               &loop_name,
                               &error))
     {
@@ -441,33 +393,20 @@ handle_loop_setup (UDisksManager          *object,
 
   loop_device = g_strdup_printf ("/dev/%s", loop_name);
 
-  /* Update the udisks loop state file (/run/udisks2/loop) with information
-   * about the new loop device created by us.
-   */
-  udisks_state_add_loop (udisks_daemon_get_state (manager->daemon),
-                        loop_device,
-                        path,
-                        fd_statbuf_valid ? fd_statbuf.st_dev : 0,
-                        caller_uid);
-
   /* Determine the resulting object */
   error = NULL;
   wait_data.loop_device = loop_device;
   wait_data.path = path;
-  udisks_daemon_util_trigger_uevent_sync (manager->daemon,
-                                          loop_device,
-                                          NULL,
-                                          UDISKS_DEFAULT_WAIT_TIMEOUT);
   loop_object = udisks_daemon_wait_for_object_sync (manager->daemon,
                                                     wait_for_loop_object,
                                                     &wait_data,
                                                     NULL,
-                                                    UDISKS_DEFAULT_WAIT_TIMEOUT,
+                                                    10, /* timeout_seconds */
                                                     &error);
   if (loop_object == NULL)
     {
       g_prefix_error (&error,
-                      "Error waiting for loop object after creating '%s': ",
+                      "Error waiting for loop object after creating %s",
                       loop_device);
       g_dbus_method_invocation_take_error (invocation, error);
       goto out;
@@ -561,13 +500,12 @@ handle_mdraid_create (UDisksManager         *_object,
   const gchar **disks = NULL;
   guint disks_top = 0;
   gboolean success = FALSE;
-  const gchar *option_bitmap = NULL;
-  const gchar *option_version = NULL;
 
   if (!udisks_daemon_util_get_caller_uid_sync (manager->daemon,
                                                invocation,
                                                NULL /* GCancellable */,
                                                &caller_uid,
+                                               NULL, NULL,
                                                &error))
     {
       g_dbus_method_invocation_return_gerror (invocation, error);
@@ -598,7 +536,6 @@ handle_mdraid_create (UDisksManager         *_object,
                                          NULL,
                                          "mdraid-create",
                                          caller_uid,
-                                         FALSE,
                                          NULL);
 
   if (job == NULL)
@@ -694,7 +631,6 @@ handle_mdraid_create (UDisksManager         *_object,
                                                  UDISKS_ERROR_FAILED,
                                                  "Object path %s for index %u is not a block device",
                                                  arg_blocks[n], n);
-          g_object_unref (object);
           success = FALSE;
           goto out;
         }
@@ -706,11 +642,9 @@ handle_mdraid_create (UDisksManager         *_object,
           g_dbus_method_invocation_return_error (invocation,
                                                  UDISKS_ERROR,
                                                  UDISKS_ERROR_FAILED,
-                                                 "Error opening device %s while creating mdraid: %m",
+                                                 "Error opening device %s: %m",
                                                  device_file);
           g_free (device_file);
-          g_object_unref (block);
-          g_object_unref (object);
           success = FALSE;
           goto out;
         }
@@ -726,7 +660,7 @@ handle_mdraid_create (UDisksManager         *_object,
   for (l = blocks; l != NULL; l = l->next)
     {
       UDisksBlock *block = UDISKS_BLOCK (l->data);
-      if (!bd_fs_wipe (udisks_block_get_device (block), TRUE, FALSE, &error))
+      if (!bd_fs_wipe (udisks_block_get_device (block), TRUE, &error))
         {
           /* no signature to remove, ignore */
           if (g_error_matches (error, BD_FS_ERROR, BD_FS_ERROR_NOFS))
@@ -734,7 +668,7 @@ handle_mdraid_create (UDisksManager         *_object,
           else
             {
               g_prefix_error (&error,
-                              "Error wiping device '%s' to be used in the RAID array: ",
+                              "Error wiping device %s to be used in the RAID array:",
                               udisks_block_get_device (block));
               g_dbus_method_invocation_take_error (invocation, error);
               success = FALSE;
@@ -768,15 +702,12 @@ handle_mdraid_create (UDisksManager         *_object,
     }
   disks[disks_top] = NULL;
 
-  g_variant_lookup (arg_options, "bitmap", "^&ay", &option_bitmap);
-  g_variant_lookup (arg_options, "version", "^&ay", &option_version);
-  if (!bd_md_create (array_name, arg_level, disks, 0, option_version, option_bitmap, arg_chunk, NULL, &error))
+  if (!bd_md_create (array_name, arg_level, disks, 0, NULL, FALSE, arg_chunk, NULL, &error))
     {
-      g_prefix_error (&error, "Error creating RAID array: ");
-      udisks_simple_job_complete (UDISKS_SIMPLE_JOB (job), FALSE, error->message);
+      g_prefix_error (&error, "Error creating RAID array:");
       g_dbus_method_invocation_take_error (invocation, error);
+      udisks_simple_job_complete (UDISKS_SIMPLE_JOB (job), FALSE, error->message);
       success = FALSE;
-      job = NULL;
       goto out;
     }
 
@@ -786,31 +717,28 @@ handle_mdraid_create (UDisksManager         *_object,
       raid_node = bd_md_node_from_name (array_name, &error);
       if (!raid_node)
         {
-          g_prefix_error (&error, "Failed to get md node for array '%s': ", array_name);
+          g_prefix_error (&error, "Failed to get md node for array %s", array_name);
           g_dbus_method_invocation_take_error (invocation, error);
           success = FALSE;
           goto out;
         }
       raid_device_file = g_strdup_printf ("/dev/%s", raid_node);
     }
+
   else
     raid_device_file = g_strdup (array_name);
 
-  /* trigger uevent on the newly created md node */
-  udisks_daemon_util_trigger_uevent_sync (manager->daemon, raid_device_file, NULL,
-                                          UDISKS_DEFAULT_WAIT_TIMEOUT);
-
   /* ... then, sit and wait for raid array object to show up */
   array_object = udisks_daemon_wait_for_object_sync (manager->daemon,
                                                      wait_for_array_object,
                                                      raid_device_file,
                                                      NULL,
-                                                     UDISKS_DEFAULT_WAIT_TIMEOUT,
+                                                     10, /* timeout_seconds */
                                                      &error);
   if (array_object == NULL)
     {
       g_prefix_error (&error,
-                      "Error waiting for array object after creating '%s': ",
+                      "Error waiting for array object after creating %s",
                       raid_device_file);
       g_dbus_method_invocation_take_error (invocation, error);
       success = FALSE;
@@ -845,13 +773,13 @@ handle_mdraid_create (UDisksManager         *_object,
                            caller_uid);
 
   /* ... wipe the created RAID array */
-  if (!bd_fs_wipe (raid_device_file, TRUE, FALSE, &error))
+  if (!bd_fs_wipe (raid_device_file, TRUE, &error))
     {
       if (g_error_matches (error, BD_FS_ERROR, BD_FS_ERROR_NOFS))
         g_clear_error (&error);
       else
         {
-          g_prefix_error (&error, "Error wiping raid device '%s': ", raid_device_file);
+          g_prefix_error (&error, "Error wiping raid device %s:", raid_device_file);
           g_dbus_method_invocation_take_error (invocation, error);
           success = FALSE;
           goto out;
@@ -893,7 +821,6 @@ handle_mdraid_create (UDisksManager         *_object,
       udisks_simple_job_complete (UDISKS_SIMPLE_JOB (job), success, NULL);
     }
 
-  g_strfreev ((gchar **) disks);
   g_free (raid_device_file);
   g_free (raid_node);
   g_free (array_name);
@@ -905,471 +832,41 @@ handle_mdraid_create (UDisksManager         *_object,
 
 /* ---------------------------------------------------------------------------------------------------- */
 
-typedef struct
+static void
+load_modules (UDisksDaemon *daemon)
 {
-  UDisksManager         *object;
-  GDBusMethodInvocation *invocation;
-  gchar                 *module_name;
-} EnableModulesData;
-
-static gboolean
-load_modules_in_idle_cb (gpointer user_data)
-{
-  EnableModulesData *data = user_data;
-  UDisksLinuxManager *manager = UDISKS_LINUX_MANAGER (data->object);
   UDisksModuleManager *module_manager;
 
-  module_manager = udisks_daemon_get_module_manager (manager->daemon);
-  if (data->module_name == NULL)
-    {
-      /* Load all modules */
-      udisks_module_manager_load_modules (module_manager);
-      /* Avoid deprecation warning from udisks_manager_complete_enable_modules() */
-      g_dbus_method_invocation_return_value (data->invocation, g_variant_new ("()"));
-    }
-  else
-    {
-      GError *error = NULL;
+  g_return_if_fail (UDISKS_IS_DAEMON (daemon));
 
-      /* Load single requested module */
-      if (! udisks_module_manager_load_single_module (module_manager, data->module_name, &error))
-        {
-          g_prefix_error (&error, "Error initializing module '%s': ", data->module_name);
-          g_warning ("%s", error->message);
-          g_dbus_method_invocation_take_error (data->invocation, error);
-        }
-      else
-        {
-          udisks_manager_complete_enable_module (data->object, data->invocation);
-        }
-    }
-  g_object_unref (data->object);
-  g_object_unref (data->invocation);
-  g_free (data->module_name);
-  g_free (data);
-
-  return G_SOURCE_REMOVE;
+  module_manager = udisks_daemon_get_module_manager (daemon);
+  udisks_module_manager_load_modules (module_manager);
 }
 
 static gboolean
-handle_enable_modules (UDisksManager         *object,
+handle_enable_modules (UDisksManager *object,
                        GDBusMethodInvocation *invocation,
-                       gboolean               arg_enable)
+                       gboolean arg_enable)
 {
   UDisksLinuxManager *manager = UDISKS_LINUX_MANAGER (object);
-  EnableModulesData *data;
 
   if (! arg_enable)
     {
       /* TODO: implement proper module unloading */
       g_dbus_method_invocation_return_error_literal (invocation,
                                                      G_IO_ERROR, G_IO_ERROR_INVALID_ARGUMENT,
-                                                     "Module unloading is not currently supported.");
+                                                     "Invalid value \"FALSE\"");
       return TRUE;
     }
 
-  if (udisks_daemon_get_disable_modules (manager->daemon))
-    {
-      g_dbus_method_invocation_return_error_literal (invocation,
-                                                     G_IO_ERROR, G_IO_ERROR_INVALID_ARGUMENT,
-                                                     "Modules are disabled by a commandline switch.");
-      return TRUE;
-    }
+  if (! udisks_daemon_get_disable_modules (manager->daemon))
+    load_modules (manager->daemon);
 
-  data = g_new0 (EnableModulesData, 1);
-  data->object = g_object_ref (object);
-  data->invocation = g_object_ref (invocation);
-  /* push to idle, process in main thread */
-  g_idle_add (load_modules_in_idle_cb, data);
+  udisks_manager_complete_enable_modules (object, invocation);
 
   return TRUE; /* returning TRUE means that we handled the method invocation */
 }
 
-static gboolean
-handle_enable_module (UDisksManager         *object,
-                      GDBusMethodInvocation *invocation,
-                      const gchar           *arg_name,
-                      gboolean               arg_enable)
-{
-  UDisksLinuxManager *manager = UDISKS_LINUX_MANAGER (object);
-  EnableModulesData *data;
-
-  if (! udisks_module_validate_name (arg_name))
-    {
-      g_dbus_method_invocation_return_error (invocation,
-                                             G_IO_ERROR, G_IO_ERROR_INVALID_ARGUMENT,
-                                             "Requested module name '%s' is not a valid udisks2 module name.",
-                                             arg_name);
-      return TRUE;
-    }
-
-  if (! arg_enable)
-    {
-      /* TODO: implement proper module unloading */
-      g_dbus_method_invocation_return_error_literal (invocation,
-                                                     G_IO_ERROR, G_IO_ERROR_INVALID_ARGUMENT,
-                                                     "Module unloading is not currently supported.");
-      return TRUE;
-    }
-
-  if (udisks_daemon_get_disable_modules (manager->daemon))
-    {
-      g_dbus_method_invocation_return_error_literal (invocation,
-                                                     G_IO_ERROR, G_IO_ERROR_INVALID_ARGUMENT,
-                                                     "Modules are disabled by a commandline switch.");
-      return TRUE;
-    }
-
-  data = g_new0 (EnableModulesData, 1);
-  data->object = g_object_ref (object);
-  data->invocation = g_object_ref (invocation);
-  data->module_name = g_strdup (arg_name);
-  /* push to idle, process in main thread */
-  g_idle_add (load_modules_in_idle_cb, data);
-
-  return TRUE; /* returning TRUE means that we handled the method invocation */
-}
-
-static gboolean
-handle_can_format (UDisksManager         *object,
-                   GDBusMethodInvocation *invocation,
-                   const gchar           *type)
-{
-  gchar *required_utility = NULL;
-  GError *error = NULL;
-  gboolean ret;
-
-  /* builtin support */
-  if (g_strcmp0 (type, "empty") == 0 || g_strcmp0 (type, "dos") == 0 || g_strcmp0 (type, "gpt") == 0)
-    {
-      udisks_manager_complete_can_format (object,
-                                          invocation,
-                                          g_variant_new ("(bs)", TRUE, ""));
-      return TRUE;
-    }
-
-  if (g_strcmp0 (type, "swap") == 0)
-    {
-      required_utility = g_strdup ("mkswap");
-      ret = bd_utils_check_util_version (required_utility, NULL, "", NULL, NULL);
-    }
-  else
-    {
-      ret = bd_fs_can_mkfs (type, NULL, &required_utility, &error);
-      if (error != NULL)
-        {
-          g_dbus_method_invocation_take_error (invocation, error);
-          return TRUE;
-        }
-    }
-
-  udisks_manager_complete_can_format (object,
-                                      invocation,
-                                      g_variant_new ("(bs)", ret, ret ? "" : required_utility));
-  g_free (required_utility);
-
-  return TRUE;
-}
-
-static gboolean
-handle_can_resize (UDisksManager         *object,
-                   GDBusMethodInvocation *invocation,
-                   const gchar           *type)
-{
-  GError *error = NULL;
-  gchar *required_utility = NULL;
-  BDFSResizeFlags mode;
-  gboolean ret;
-
-  ret = bd_fs_can_resize (type, &mode, &required_utility, &error);
-
-  if (error != NULL)
-    {
-      g_dbus_method_invocation_take_error (invocation, error);
-      return TRUE;
-    }
-
-  udisks_manager_complete_can_resize (object,
-                                      invocation,
-                                      g_variant_new ("(bts)", ret, (guint64) mode,
-                                                     ret ? "" : required_utility));
-
-  g_free (required_utility);
-
-  return TRUE;
-}
-
-static gboolean
-handle_can_check (UDisksManager         *object,
-                  GDBusMethodInvocation *invocation,
-                  const gchar           *type)
-{
-  GError *error = NULL;
-  gchar *required_utility = NULL;
-  gboolean ret;
-
-  ret = bd_fs_can_check (type, &required_utility, &error);
-
-  if (error != NULL)
-    {
-      g_dbus_method_invocation_take_error (invocation, error);
-      return TRUE;
-    }
-
-  udisks_manager_complete_can_check (object,
-                                     invocation,
-                                     g_variant_new ("(bs)", ret,
-                                                    ret ? "" : required_utility));
-
-  g_free (required_utility);
-
-  return TRUE;
-}
-
-static gboolean
-handle_can_repair (UDisksManager         *object,
-                   GDBusMethodInvocation *invocation,
-                   const gchar           *type)
-{
-  GError *error = NULL;
-  gchar *required_utility = NULL;
-  gboolean ret;
-
-  ret = bd_fs_can_repair (type, &required_utility, &error);
-
-  if (error != NULL)
-    {
-      g_dbus_method_invocation_take_error (invocation, error);
-      return TRUE;
-    }
-
-  udisks_manager_complete_can_repair (object,
-                                      invocation,
-                                      g_variant_new ("(bs)", ret,
-                                                     ret ? "" : required_utility));
-
-  g_free (required_utility);
-
-  return TRUE;
-}
-
-
-static GSList*
-get_block_objects (UDisksManager *manager,
-                   guint         *num_blocks)
-{
-  UDisksLinuxManager *linux_manager = UDISKS_LINUX_MANAGER (manager);
-  GDBusObjectManagerServer *object_manager = NULL;
-  GList *objects = NULL;
-  GList *objects_p = NULL;
-  GSList *ret = NULL;
-
-  object_manager = udisks_daemon_get_object_manager (linux_manager->daemon);
-  objects = g_dbus_object_manager_get_objects (G_DBUS_OBJECT_MANAGER (object_manager));
-
-  for (objects_p = objects; objects_p != NULL; objects_p = objects_p->next)
-    {
-      UDisksObject *object = UDISKS_OBJECT (objects_p->data);
-      UDisksBlock *block;
-
-      block = udisks_object_get_block (object);
-      if (block != NULL)
-        {
-          ret = g_slist_prepend (ret, block);
-          (*num_blocks)++;
-        }
-    }
-
-  g_list_free_full (objects, g_object_unref);
-  ret = g_slist_reverse (ret);
-  return ret;
-}
-
-static GSList*
-get_drive_objects (UDisksManager *manager,
-                   guint         *num_drives)
-{
-  UDisksLinuxManager *linux_manager = UDISKS_LINUX_MANAGER (manager);
-  GDBusObjectManagerServer *object_manager = NULL;
-  GList *objects = NULL;
-  GList *objects_p = NULL;
-  GSList *ret = NULL;
-
-  object_manager = udisks_daemon_get_object_manager (linux_manager->daemon);
-  objects = g_dbus_object_manager_get_objects (G_DBUS_OBJECT_MANAGER (object_manager));
-
-  for (objects_p = objects; objects_p != NULL; objects_p = objects_p->next)
-    {
-      UDisksObject *object = UDISKS_OBJECT (objects_p->data);
-      UDisksDrive *drive;
-
-      drive = udisks_object_get_drive (object);
-      if (drive != NULL)
-        {
-          ret = g_slist_prepend (ret, drive);
-          (*num_drives)++;
-        }
-    }
-
-  g_list_free_full (objects, g_object_unref);
-  ret = g_slist_reverse (ret);
-  return ret;
-}
-
-static gboolean
-handle_get_block_devices (UDisksManager         *object,
-                          GDBusMethodInvocation *invocation,
-                          GVariant              *arg_options)
-{
-  GSList *blocks = NULL;
-  GSList *blocks_p = NULL;
-  const gchar **block_paths = NULL;
-  guint num_blocks = 0;
-  guint i = 0;
-
-  blocks = get_block_objects (object, &num_blocks);
-  block_paths = g_new0 (const gchar *, num_blocks + 1);
-
-  for (blocks_p = blocks; blocks_p != NULL; blocks_p = blocks_p->next) {
-	  GDBusObject * block_object = g_dbus_interface_get_object (G_DBUS_INTERFACE (blocks_p->data));
-	  if (block_object)
-		  block_paths[i++] = g_dbus_object_get_object_path (block_object);
-  }
-
-  udisks_manager_complete_get_block_devices  (object,
-                                              invocation,
-                                              block_paths);
-
-  g_free (block_paths);
-  g_slist_free_full (blocks, g_object_unref);
-
-  return TRUE;  /* returning TRUE means that we handled the method invocation */
-}
-
-static gboolean
-handle_get_drives (UDisksManager         *object,
-                   GDBusMethodInvocation *invocation,
-                   GVariant              *arg_options)
-{
-  GSList *drives = NULL;
-  GSList *drives_p = NULL;
-  const gchar **drive_paths = NULL;
-  guint num_drives = 0;
-  guint i = 0;
-
-  drives = get_drive_objects (object, &num_drives);
-  drive_paths = g_new0 (const gchar *, num_drives + 1);
-
-  for (drives_p = drives; drives_p != NULL; drives_p = drives_p->next)
-    {
-      GDBusObject *drive_object = g_dbus_interface_get_object (G_DBUS_INTERFACE (drives_p->data));
-      if (drive_object)
-        drive_paths[i++] = g_dbus_object_get_object_path (drive_object);
-    }
-
-  udisks_manager_complete_get_drives (object,
-                                      invocation,
-                                      drive_paths);
-
-  g_free (drive_paths);
-  g_slist_free_full (drives, g_object_unref);
-
-  return TRUE;  /* returning TRUE means that we handled the method invocation */
-}
-
-static inline gboolean
-match_id_format (UDisksLinuxBlock *block, const gchar *key, const gchar *val)
-{
-  gchar *s;
-  gboolean ret;
-
-  s = g_strdup_printf ("%s=%s", key, val);
-  ret = udisks_linux_block_matches_id (block, s);
-  g_free (s);
-
-  return ret;
-}
-
-static gboolean
-handle_resolve_device (UDisksManager         *object,
-                       GDBusMethodInvocation *invocation,
-                       GVariant              *arg_devspec,
-                       GVariant              *arg_options)
-{
-  const gchar *devpath = NULL;
-  const gchar *devuuid = NULL;
-  const gchar *devlabel = NULL;
-  const gchar *partuuid = NULL;
-  const gchar *partlabel = NULL;
-
-  GSList *blocks = NULL;
-  GSList *blocks_p = NULL;
-  guint num_blocks = 0;
-
-  GSList *ret = NULL;
-  GSList *ret_p = NULL;
-  guint num_found = 0;
-  const gchar **ret_paths = NULL;
-
-  guint i = 0;
-
-  g_variant_lookup (arg_devspec, "path", "&s", &devpath);
-  g_variant_lookup (arg_devspec, "uuid", "&s", &devuuid);
-  g_variant_lookup (arg_devspec, "label", "&s", &devlabel);
-  g_variant_lookup (arg_devspec, "partuuid", "&s", &partuuid);
-  g_variant_lookup (arg_devspec, "partlabel", "&s", &partlabel);
-
-  if (!devpath && !devuuid && !devlabel && !partuuid && !partlabel)
-    {
-      g_dbus_method_invocation_return_error_literal (invocation, UDISKS_ERROR, UDISKS_ERROR_FAILED,
-                                                     "Invalid device specification provided");
-      return TRUE;
-    }
-
-  blocks = get_block_objects (object, &num_blocks);
-
-  for (blocks_p = blocks; blocks_p != NULL; blocks_p = blocks_p->next)
-    {
-      UDisksLinuxBlock *block = UDISKS_LINUX_BLOCK (blocks_p->data);
-      gboolean found = TRUE;
-
-      if (devpath != NULL)
-          found = udisks_linux_block_matches_id (block, devpath);
-      if (devuuid != NULL)
-          found = found && match_id_format (block, "UUID", devuuid);
-      if (devlabel != NULL)
-          found = found && match_id_format (block, "LABEL", devlabel);
-      if (partuuid != NULL)
-          found = found && match_id_format (block, "PARTUUID", partuuid);
-      if (partlabel != NULL)
-          found = found && match_id_format (block, "PARTLABEL", partlabel);
-
-      if (found)
-        {
-          ret = g_slist_prepend (ret, block);
-          num_found++;
-        }
-    }
-
-  ret_paths = g_new0 (const gchar *, num_found + 1);
-  for (i = 0,ret_p = ret; ret_p != NULL; ret_p = ret_p->next)
-    {
-      GDBusObject *block_object = g_dbus_interface_get_object (G_DBUS_INTERFACE (ret_p->data));
-      if (block_object)
-        ret_paths[i++] = g_dbus_object_get_object_path (block_object);
-    }
-
-  udisks_manager_complete_resolve_device (object,
-                                          invocation,
-                                          ret_paths);
-
-  g_free (ret_paths);
-  g_slist_free_full (blocks, g_object_unref);
-  g_slist_free (ret);
-
-  return TRUE;  /* returning TRUE means that we handled the method invocation */
-}
-
 /* ---------------------------------------------------------------------------------------------------- */
 
 static void
@@ -1378,12 +875,4 @@ manager_iface_init (UDisksManagerIface *iface)
   iface->handle_loop_setup = handle_loop_setup;
   iface->handle_mdraid_create = handle_mdraid_create;
   iface->handle_enable_modules = handle_enable_modules;
-  iface->handle_enable_module = handle_enable_module;
-  iface->handle_can_format = handle_can_format;
-  iface->handle_can_resize = handle_can_resize;
-  iface->handle_can_check = handle_can_check;
-  iface->handle_can_repair = handle_can_repair;
-  iface->handle_get_block_devices = handle_get_block_devices;
-  iface->handle_resolve_device = handle_resolve_device;
-  iface->handle_get_drives = handle_get_drives;
 }
