@@ -27,10 +27,8 @@
 #include <string.h>
 #include <stdlib.h>
 #include <sys/sysmacros.h>
-#include <sys/ioctl.h>
-#include <linux/fs.h>
-#include <uuid.h>
 #include <glib-unix.h>
+
 #include <glib/gstdio.h>
 
 #include <blockdev/part.h>
@@ -43,7 +41,6 @@
 #include "udiskslinuxdevice.h"
 #include "udiskslinuxblock.h"
 #include "udiskssimplejob.h"
-#include "udisksstate.h"
 
 /**
  * SECTION:udiskslinuxpartition
@@ -133,9 +130,12 @@ check_authorization (UDisksPartition       *partition,
                                                invocation,
                                                NULL /* GCancellable */,
                                                caller_uid,
+                                               NULL,
+                                               NULL,
                                                &error))
     {
-      g_dbus_method_invocation_take_error (invocation, error);
+      g_dbus_method_invocation_return_gerror (invocation, error);
+      g_clear_error (&error);
       goto out;
     }
 
@@ -175,57 +175,8 @@ out:
   return rc;
 }
 
-static gboolean
-is_valid_uuid (const gchar *str)
-{
-  gchar *lowercase;
-  gint ret;
-  uuid_t uu;
-
-  if (!g_str_is_ascii (str))
-    return FALSE;
-
-  lowercase = g_ascii_strdown (str, -1);
-  ret = uuid_parse (lowercase, uu);
-  g_free (lowercase);
-
-  return ret == 0;
-}
-
 /* ---------------------------------------------------------------------------------------------------- */
 
-static void update_partitions_list (UDisksObject           *disk_object,
-                                    UDisksLinuxBlockObject *part_object)
-{
-  UDisksPartitionTable *table = NULL;
-  gchar **partitions = NULL;
-  const gchar *object_path = NULL;
-  guint num_parts = 0;
-
-  object_path = g_dbus_object_get_object_path (G_DBUS_OBJECT (part_object));
-  if (object_path == NULL)
-    return;
-
-  table = udisks_object_peek_partition_table (disk_object);
-  if (table == NULL)
-    return;
-
-  partitions = udisks_partition_table_dup_partitions (table);
-  if (partitions != NULL && g_strv_contains ((const gchar **) partitions, object_path))
-    /* this partition is already in the property */
-    goto out;
-
-  num_parts = partitions ? g_strv_length (partitions) : 0;
-  partitions = g_realloc (partitions, (num_parts + 2) * sizeof (gchar *));
-  partitions[num_parts] = g_strdup (object_path);
-  partitions[num_parts + 1] = NULL;
-
-  udisks_partition_table_set_partitions (table, (const gchar**) partitions);
-
-out:
-  g_strfreev (partitions);
-}
-
 /**
  * udisks_linux_partition_update:
  * @partition: A #UDisksLinuxPartition.
@@ -259,7 +210,7 @@ udisks_linux_partition_update (UDisksLinuxPartition   *partition,
       type = g_udev_device_get_property (device->udev_device, "ID_PART_ENTRY_TYPE");
       offset = g_udev_device_get_property_as_uint64 (device->udev_device, "ID_PART_ENTRY_OFFSET") * G_GUINT64_CONSTANT (512);
       size = g_udev_device_get_property_as_uint64 (device->udev_device, "ID_PART_ENTRY_SIZE") * G_GUINT64_CONSTANT (512);
-      name = udisks_decode_udev_string (g_udev_device_get_property (device->udev_device, "ID_PART_ENTRY_NAME"), NULL);
+      name = udisks_decode_udev_string (g_udev_device_get_property (device->udev_device, "ID_PART_ENTRY_NAME"));
       uuid = g_udev_device_get_property (device->udev_device, "ID_PART_ENTRY_UUID");
       flags = g_udev_device_get_property_as_uint64 (device->udev_device, "ID_PART_ENTRY_FLAGS");
 
@@ -312,10 +263,8 @@ udisks_linux_partition_update (UDisksLinuxPartition   *partition,
         }
     }
 
-  if (disk_block_object != NULL) {
+  if (disk_block_object != NULL)
     table_object_path = g_dbus_object_get_object_path (G_DBUS_OBJECT (disk_block_object));
-    update_partitions_list (disk_block_object, object);
-  }
 
   udisks_partition_set_number (UDISKS_PARTITION (partition), number);
   udisks_partition_set_type_ (UDISKS_PARTITION (partition), type);
@@ -328,8 +277,6 @@ udisks_linux_partition_update (UDisksLinuxPartition   *partition,
   udisks_partition_set_is_container (UDISKS_PARTITION (partition), is_container);
   udisks_partition_set_is_contained (UDISKS_PARTITION (partition), is_contained);
 
-  g_dbus_interface_skeleton_flush (G_DBUS_INTERFACE_SKELETON (partition));
-
   g_free (name);
   g_clear_object (&device);
   g_clear_object (&disk_block_object);
@@ -346,7 +293,6 @@ handle_set_flags (UDisksPartition       *partition,
   UDisksBlock *block = NULL;
   UDisksObject *object = NULL;
   UDisksDaemon *daemon = NULL;
-  UDisksState *state = NULL;
   gchar *device_name = NULL;
   UDisksObject *partition_table_object = NULL;
   UDisksPartitionTable *partition_table = NULL;
@@ -356,6 +302,7 @@ handle_set_flags (UDisksPartition       *partition,
   gchar *partition_name = NULL;
   gboolean bootable = FALSE;
   GError *error = NULL;
+  guint64 bd_flags = 0;
   UDisksBaseJob *job = NULL;
 
   if (!check_authorization (partition, invocation, options, &caller_uid))
@@ -366,12 +313,11 @@ handle_set_flags (UDisksPartition       *partition,
   object = udisks_daemon_util_dup_object (partition, &error);
   if (object == NULL)
     {
-      g_dbus_method_invocation_return_gerror (invocation, error);
+      g_dbus_method_invocation_take_error (invocation, error);
       goto out;
     }
 
   daemon = udisks_linux_block_object_get_daemon (UDISKS_LINUX_BLOCK_OBJECT (object));
-  state = udisks_daemon_get_state (daemon);
   block = udisks_object_get_block (object);
   partition_table_object = udisks_daemon_find_object (daemon, udisks_partition_get_table (partition));
   partition_table = udisks_object_get_partition_table (partition_table_object);
@@ -379,9 +325,6 @@ handle_set_flags (UDisksPartition       *partition,
   device_name = udisks_block_dup_device (partition_table_block);
   partition_name = udisks_block_dup_device (block);
 
-  udisks_linux_block_object_lock_for_cleanup (UDISKS_LINUX_BLOCK_OBJECT (object));
-  udisks_state_check_block (state, udisks_linux_block_object_get_device_number (UDISKS_LINUX_BLOCK_OBJECT (object)));
-
   /* hold a file descriptor open to suppress BLKRRPART generated by the tools */
   fd = open (partition_name, O_RDONLY);
 
@@ -389,7 +332,6 @@ handle_set_flags (UDisksPartition       *partition,
                                          UDISKS_OBJECT (object),
                                          "partition-modify",
                                          caller_uid,
-                                         FALSE,
                                          NULL);
 
   if (job == NULL)
@@ -401,10 +343,19 @@ handle_set_flags (UDisksPartition       *partition,
 
   if (g_strcmp0 (udisks_partition_table_get_type_ (partition_table), "gpt") == 0)
     {
-      if (!bd_part_set_part_attributes (device_name,
-                                        partition_name,
-                                        flags,
-                                        &error))
+      if (flags & 1) /* 1 << 0 */
+          bd_flags |= BD_PART_FLAG_GPT_SYSTEM_PART;
+      if (flags & 0x1000000000000000) /* 1 << 60 */
+          bd_flags |= BD_PART_FLAG_GPT_READ_ONLY;
+      if (flags & 0x4000000000000000) /* 1 << 62 */
+          bd_flags |= BD_PART_FLAG_GPT_HIDDEN;
+      if (flags & 0x8000000000000000) /* 1 << 63 */
+          bd_flags |= BD_PART_FLAG_GPT_NO_AUTOMOUNT;
+
+      if (!bd_part_set_part_flags (device_name,
+                                   partition_name,
+                                   bd_flags,
+                                   &error))
         {
           g_dbus_method_invocation_return_error (invocation,
                                                  UDISKS_ERROR,
@@ -421,10 +372,11 @@ handle_set_flags (UDisksPartition       *partition,
       /* 7th bit - the partition is marked as bootable */
       bootable = !!(flags & 1 << 7); /* Narrow possible values to TRUE/FALSE */
 
-      if (!bd_part_set_part_bootable (device_name,
-                                      partition_name,
-                                      bootable,
-                                      &error))
+      if (!bd_part_set_part_flag (device_name,
+                                  partition_name,
+                                  BD_PART_FLAG_BOOT,
+                                  bootable,
+                                  &error))
       {
         g_dbus_method_invocation_return_error (invocation,
                                                UDISKS_ERROR,
@@ -441,24 +393,19 @@ handle_set_flags (UDisksPartition       *partition,
         g_dbus_method_invocation_return_error (invocation,
                                                UDISKS_ERROR,
                                                UDISKS_ERROR_NOT_SUPPORTED,
-                                               "No support for setting partition flags on a partition table of type `%s'",
+                                               "No support for modifying a partition a table of type `%s'",
                                                udisks_partition_table_get_type_ (partition_table));
         udisks_simple_job_complete (UDISKS_SIMPLE_JOB (job), FALSE, NULL);
         goto out;
       }
 
-  udisks_linux_block_object_trigger_uevent_sync (UDISKS_LINUX_BLOCK_OBJECT (object),
-                                                 UDISKS_DEFAULT_WAIT_TIMEOUT);
+  udisks_linux_block_object_trigger_uevent (UDISKS_LINUX_BLOCK_OBJECT (object));
   udisks_partition_complete_set_flags (partition, invocation);
   udisks_simple_job_complete (UDISKS_SIMPLE_JOB (job), TRUE, NULL);
 
  out:
   if (fd != -1)
     close (fd);
-  if (object != NULL)
-    udisks_linux_block_object_release_cleanup_lock (UDISKS_LINUX_BLOCK_OBJECT (object));
-  if (state != NULL)
-    udisks_state_check (state);
   g_free (device_name);
   g_free (partition_name);
   g_clear_error (&error);
@@ -484,7 +431,6 @@ handle_set_name (UDisksPartition       *partition,
   UDisksBlock *block = NULL;
   UDisksObject *object = NULL;
   UDisksDaemon *daemon = NULL;
-  UDisksState *state = NULL;
   gchar *device_name = NULL;
   gchar *partition_name = NULL;
   UDisksObject *partition_table_object = NULL;
@@ -503,17 +449,13 @@ handle_set_name (UDisksPartition       *partition,
   object = udisks_daemon_util_dup_object (partition, &error);
   if (object == NULL)
     {
-      g_dbus_method_invocation_return_gerror (invocation, error);
+      g_dbus_method_invocation_take_error (invocation, error);
       goto out;
     }
 
   daemon = udisks_linux_block_object_get_daemon (UDISKS_LINUX_BLOCK_OBJECT (object));
-  state = udisks_daemon_get_state (daemon);
   block = udisks_object_get_block (object);
 
-  udisks_linux_block_object_lock_for_cleanup (UDISKS_LINUX_BLOCK_OBJECT (object));
-  udisks_state_check_block (state, udisks_linux_block_object_get_device_number (UDISKS_LINUX_BLOCK_OBJECT (object)));
-
   partition_table_object = udisks_daemon_find_object (daemon, udisks_partition_get_table (partition));
   partition_table = udisks_object_get_partition_table (partition_table_object);
   partition_table_block = udisks_object_get_block (partition_table_object);
@@ -528,7 +470,6 @@ handle_set_name (UDisksPartition       *partition,
                                          UDISKS_OBJECT (object),
                                          "partition-modify",
                                          caller_uid,
-                                         FALSE,
                                          NULL);
 
   if (job == NULL)
@@ -570,24 +511,18 @@ handle_set_name (UDisksPartition       *partition,
       g_dbus_method_invocation_return_error (invocation,
                                              UDISKS_ERROR,
                                              UDISKS_ERROR_NOT_SUPPORTED,
-                                             "No support for setting partition name on a partition table of type `%s'",
+                                             "No support for modifying a partition a table of type `%s'",
                                              udisks_partition_table_get_type_ (partition_table));
-      udisks_simple_job_complete (UDISKS_SIMPLE_JOB (job), FALSE, NULL);
       goto out;
     }
 
-  udisks_linux_block_object_trigger_uevent_sync (UDISKS_LINUX_BLOCK_OBJECT (object),
-                                                 UDISKS_DEFAULT_WAIT_TIMEOUT);
+  udisks_linux_block_object_trigger_uevent (UDISKS_LINUX_BLOCK_OBJECT (object));
   udisks_partition_complete_set_name (partition, invocation);
   udisks_simple_job_complete (UDISKS_SIMPLE_JOB (job), TRUE, NULL);
 
  out:
   if (fd != -1)
     close (fd);
-  if (object != NULL)
-    udisks_linux_block_object_release_cleanup_lock (UDISKS_LINUX_BLOCK_OBJECT (object));
-  if (state != NULL)
-    udisks_state_check (state);
   g_free (device_name);
   g_free (partition_name);
   g_clear_error (&error);
@@ -604,126 +539,36 @@ handle_set_name (UDisksPartition       *partition,
 /* ---------------------------------------------------------------------------------------------------- */
 
 static gboolean
-handle_set_uuid (UDisksPartition       *partition,
-                 GDBusMethodInvocation *invocation,
-                 const gchar           *arg_uuid,
-                 GVariant              *arg_options)
+is_valid_uuid (const gchar *str)
 {
-  UDisksBlock *block = NULL;
-  UDisksObject *object = NULL;
-  UDisksDaemon *daemon = NULL;
-  UDisksState *state = NULL;
-  gchar *device_name = NULL;
-  gchar *partition_name = NULL;
-  UDisksObject *partition_table_object = NULL;
-  UDisksPartitionTable *partition_table = NULL;
-  UDisksBlock *partition_table_block = NULL;
-  gint fd = -1;
-  uid_t caller_uid;
-  GError *error = NULL;
-  UDisksBaseJob *job = NULL;
+  gboolean ret = FALSE;
+  guint groups[] = {8, 4, 4, 4, 12, 0};
+  guint pos, n, m;
 
-  if (!check_authorization (partition, invocation, arg_options, &caller_uid))
+  if (strlen (str) != 36)
+    goto out;
+
+  pos = 0;
+  for (n = 0; groups[n] != 0; n++)
     {
-      goto out;
+      if (pos > 0)
+        {
+          if (str[pos++] != '-')
+            goto out;
+        }
+      for (m = 0; m < groups[n]; m++)
+        {
+          if (!g_ascii_isxdigit (str[pos++]))
+            goto out;
+        }
     }
 
-  object = udisks_daemon_util_dup_object (partition, &error);
-  if (object == NULL)
-    {
-      g_dbus_method_invocation_return_gerror (invocation, error);
-      goto out;
-    }
-
-  daemon = udisks_linux_block_object_get_daemon (UDISKS_LINUX_BLOCK_OBJECT (object));
-  state = udisks_daemon_get_state (daemon);
-  block = udisks_object_get_block (object);
-
-  udisks_linux_block_object_lock_for_cleanup (UDISKS_LINUX_BLOCK_OBJECT (object));
-  udisks_state_check_block (state, udisks_linux_block_object_get_device_number (UDISKS_LINUX_BLOCK_OBJECT (object)));
-
-  partition_table_object = udisks_daemon_find_object (daemon, udisks_partition_get_table (partition));
-  partition_table = udisks_object_get_partition_table (partition_table_object);
-  partition_table_block = udisks_object_get_block (partition_table_object);
-
-  if (!is_valid_uuid (arg_uuid))
-    {
-      g_dbus_method_invocation_return_error (invocation, UDISKS_ERROR, UDISKS_ERROR_FAILED,
-                                             "Provided UUID is not a valid RFC-4122 UUID");
-      goto out;
-    }
-
-  if (g_strcmp0 (udisks_partition_table_get_type_ (partition_table), "gpt") != 0)
-    {
-      g_dbus_method_invocation_return_error (invocation,
-                                             UDISKS_ERROR,
-                                             UDISKS_ERROR_NOT_SUPPORTED,
-                                             "Setting partition UUID is not supported on a partition table of type %s",
-                                             udisks_partition_table_get_type_ (partition_table));
-      goto out;
-    }
-
-  partition_name = udisks_block_dup_device (block);
-
-  /* hold a file descriptor open to suppress BLKRRPART generated by the tools */
-  fd = open (partition_name, O_RDONLY);
-
-  job = udisks_daemon_launch_simple_job (daemon,
-                                         UDISKS_OBJECT (object),
-                                         "partition-modify",
-                                         caller_uid,
-                                         FALSE,
-                                         NULL);
-
-  if (job == NULL)
-    {
-      g_dbus_method_invocation_return_error (invocation, UDISKS_ERROR, UDISKS_ERROR_FAILED,
-                                             "Failed to create a job object");
-      goto out;
-    }
-
-  if (!bd_part_set_part_uuid (udisks_block_get_device (partition_table_block),
-                              partition_name,
-                              arg_uuid,
-                              &error))
-    {
-      g_dbus_method_invocation_return_error (invocation,
-                                             UDISKS_ERROR,
-                                             UDISKS_ERROR_FAILED,
-                                             "Error setting partition UUID on %s: %s",
-                                             udisks_block_get_device (block),
-                                             error->message);
-      udisks_simple_job_complete (UDISKS_SIMPLE_JOB (job), FALSE, error->message);
-      goto out;
-    }
-
-  udisks_linux_block_object_trigger_uevent_sync (UDISKS_LINUX_BLOCK_OBJECT (object),
-                                                 UDISKS_DEFAULT_WAIT_TIMEOUT);
-  udisks_partition_complete_set_uuid (partition, invocation);
-  udisks_simple_job_complete (UDISKS_SIMPLE_JOB (job), TRUE, NULL);
+  ret = TRUE;
 
  out:
-  if (fd != -1)
-    close (fd);
-  if (object != NULL)
-    udisks_linux_block_object_release_cleanup_lock (UDISKS_LINUX_BLOCK_OBJECT (object));
-  if (state != NULL)
-    udisks_state_check (state);
-  g_free (device_name);
-  g_free (partition_name);
-  g_clear_error (&error);
-  g_clear_object (&object);
-  g_clear_object (&block);
-  g_clear_object (&partition_table_object);
-  g_clear_object (&partition_table);
-  g_clear_object (&partition_table_block);
-  g_clear_object (&object);
-
-  return TRUE; /* returning TRUE means that we handled the method invocation */
+  return ret;
 }
 
-/* ---------------------------------------------------------------------------------------------------- */
-
 /**
  * udisks_linux_partition_set_type_sync:
  * @partition: A #UDisksLinuxPartition.
@@ -778,7 +623,6 @@ udisks_linux_partition_set_type_sync (UDisksLinuxPartition  *partition,
                                          UDISKS_OBJECT (object),
                                          "partition-modify",
                                          caller_uid,
-                                         FALSE,
                                          NULL);
 
   if (job == NULL)
@@ -855,15 +699,12 @@ udisks_linux_partition_set_type_sync (UDisksLinuxPartition  *partition,
       g_set_error (error,
                    UDISKS_ERROR,
                    UDISKS_ERROR_NOT_SUPPORTED,
-                   "No support for setting partition type on a partition table of type `%s'",
+                   "No support for modifying a partition a table of type `%s'",
                    udisks_partition_table_get_type_ (partition_table));
       udisks_simple_job_complete (UDISKS_SIMPLE_JOB (job), FALSE, (*error)->message);
       goto out;
     }
 
-  udisks_linux_block_object_trigger_uevent_sync (UDISKS_LINUX_BLOCK_OBJECT (object),
-                                                 UDISKS_DEFAULT_WAIT_TIMEOUT);
-
   ret = TRUE;
   udisks_simple_job_complete (UDISKS_SIMPLE_JOB (job), TRUE, NULL);
 
@@ -911,157 +752,6 @@ handle_set_type (UDisksPartition       *partition,
 
 /* ---------------------------------------------------------------------------------------------------- */
 
-typedef struct
-{
-  const gchar *object_path;
-  guint64      new_size;
-} WaitForPartitionResizeData;
-
-static UDisksObject *
-wait_for_partition_resize (UDisksDaemon *daemon,
-                           gpointer      user_data)
-{
-  WaitForPartitionResizeData *data = user_data;
-  UDisksObject *object = NULL;
-  UDisksPartition *partition = NULL;
-
-  object = udisks_daemon_find_object (daemon, data->object_path);
-
-  if (object != NULL)
-    {
-      partition = udisks_object_peek_partition (object);
-      if (udisks_object_peek_block (object) == NULL ||
-          partition == NULL || udisks_partition_get_size (partition) != data->new_size)
-        {
-          g_clear_object (&object);
-        }
-    }
-
-  return object;
-}
-
-/* runs in thread dedicated to handling @invocation */
-static gboolean
-handle_resize (UDisksPartition       *partition,
-               GDBusMethodInvocation *invocation,
-               guint64                size,
-               GVariant              *options)
-{
-  UDisksBlock *block = NULL;
-  UDisksObject *object = NULL;
-  UDisksDaemon *daemon = NULL;
-  UDisksState *state = NULL;
-  UDisksObject *partition_table_object = NULL;
-  UDisksBlock *partition_table_block = NULL;
-  uid_t caller_uid;
-  GError *error = NULL;
-  UDisksBaseJob *job = NULL;
-  UDisksObject *partition_object = NULL;
-  WaitForPartitionResizeData wait_data;
-  gint fd = 0;
-  const gchar *part = NULL;
-
-  if (!check_authorization (partition, invocation, options, &caller_uid))
-    {
-      goto out;
-    }
-
-  object = udisks_daemon_util_dup_object (partition, &error);
-  if (object == NULL)
-    {
-      g_dbus_method_invocation_return_gerror (invocation, error);
-      goto out;
-    }
-
-  wait_data.object_path = g_dbus_object_get_object_path (G_DBUS_OBJECT (object));
-  wait_data.new_size = 0; /* hit timeout in case of error */
-  daemon = udisks_linux_block_object_get_daemon (UDISKS_LINUX_BLOCK_OBJECT (object));
-  state = udisks_daemon_get_state (daemon);
-  block = udisks_object_get_block (object);
-  part = udisks_block_get_device (block);
-  partition_table_object = udisks_daemon_find_object (daemon, udisks_partition_get_table (partition));
-  partition_table_block = udisks_object_get_block (partition_table_object);
-
-  udisks_linux_block_object_lock_for_cleanup (UDISKS_LINUX_BLOCK_OBJECT (object));
-  udisks_state_check_block (state, udisks_linux_block_object_get_device_number (UDISKS_LINUX_BLOCK_OBJECT (object)));
-
-  job = udisks_daemon_launch_simple_job (daemon,
-                                         UDISKS_OBJECT (object),
-                                         "partition-modify",
-                                         caller_uid,
-                                         FALSE,
-                                         NULL);
-
-  if (job == NULL)
-    {
-      g_dbus_method_invocation_return_error (invocation, UDISKS_ERROR, UDISKS_ERROR_FAILED,
-                                             "Failed to create a job object");
-      goto out;
-    }
-
-  if (! bd_part_resize_part (udisks_block_get_device (partition_table_block),
-                             udisks_block_get_device (block),
-                             size, BD_PART_ALIGN_OPTIMAL, &error))
-    {
-      g_dbus_method_invocation_return_error (invocation,
-                                             UDISKS_ERROR,
-                                             UDISKS_ERROR_FAILED,
-                                             "Error resizing partition %s: %s",
-                                             udisks_block_get_device (block),
-                                             error->message);
-      udisks_simple_job_complete (UDISKS_SIMPLE_JOB (job), FALSE, error->message);
-      goto out;
-    }
-
-  /* Wait for partition property to be updated so that the partition interface
-   * will not disappear shortly after this method returns.
-   * Clients could either explicitly wait for an interface or try
-   * udisks_client_settle() to wait for interfaces to be present.
-   * If the partition size wasn't changed then there won't be any reappearing
-   * of the partition node or the interfaces.
-   */
-
-  fd = open (part, O_RDONLY);
-  if (fd != -1) {
-    if (ioctl (fd, BLKGETSIZE64, &wait_data.new_size) == -1) {
-        udisks_warning ("Could not query new partition size for %s", part);
-    }
-
-    close (fd);
-  } else {
-    udisks_warning ("Could not open %s to query new partition size", part);
-  }
-
-  udisks_linux_block_object_trigger_uevent_sync (UDISKS_LINUX_BLOCK_OBJECT (partition_table_object ? partition_table_object : object),
-                                                 UDISKS_DEFAULT_WAIT_TIMEOUT);
-  partition_object = udisks_daemon_wait_for_object_sync (daemon,
-                                                         wait_for_partition_resize,
-                                                         &wait_data,
-                                                         NULL,
-                                                         UDISKS_DEFAULT_WAIT_TIMEOUT,
-                                                         NULL);
-
-  udisks_partition_complete_resize (partition, invocation);
-  udisks_simple_job_complete (UDISKS_SIMPLE_JOB (job), TRUE, NULL);
-
- out:
-  if (object != NULL)
-    udisks_linux_block_object_release_cleanup_lock (UDISKS_LINUX_BLOCK_OBJECT (object));
-  if (state != NULL)
-    udisks_state_check (state);
-  g_clear_error (&error);
-  g_clear_object (&object);
-  g_clear_object (&block);
-  g_clear_object (&partition_object);
-  g_clear_object (&partition_table_object);
-  g_clear_object (&partition_table_block);
-
-  return TRUE; /* returning TRUE means that we handled the method invocation */
-
-}
-
-/* ---------------------------------------------------------------------------------------------------- */
-
 /* runs in thread dedicated to handling @invocation */
 static gboolean
 handle_delete (UDisksPartition       *partition,
@@ -1071,7 +761,6 @@ handle_delete (UDisksPartition       *partition,
   UDisksBlock *block = NULL;
   UDisksObject *object = NULL;
   UDisksDaemon *daemon = NULL;
-  UDisksState *state = NULL;
   gchar *device_name = NULL;
   gchar *partition_name = NULL;
   UDisksObject *partition_table_object = NULL;
@@ -1091,25 +780,23 @@ handle_delete (UDisksPartition       *partition,
   object = udisks_daemon_util_dup_object (partition, &error);
   if (object == NULL)
     {
-      g_dbus_method_invocation_return_gerror (invocation, error);
+      g_dbus_method_invocation_take_error (invocation, error);
       goto out;
     }
 
   daemon = udisks_linux_block_object_get_daemon (UDISKS_LINUX_BLOCK_OBJECT (object));
-  state = udisks_daemon_get_state (daemon);
   block = udisks_object_get_block (object);
   partition_table_object = udisks_daemon_find_object (daemon, udisks_partition_get_table (partition));
   partition_table_block = udisks_object_get_block (partition_table_object);
 
-  udisks_linux_block_object_lock_for_cleanup (UDISKS_LINUX_BLOCK_OBJECT (object));
-  udisks_state_check_block (state, udisks_linux_block_object_get_device_number (UDISKS_LINUX_BLOCK_OBJECT (object)));
-
   if (teardown_flag)
     {
       if (!udisks_linux_block_teardown (block, invocation, options, &error))
         {
           if (invocation != NULL)
-            g_dbus_method_invocation_return_gerror (invocation, error);
+            g_dbus_method_invocation_take_error (invocation, error);
+          else
+            g_clear_error (&error);
           goto out;
         }
     }
@@ -1121,7 +808,6 @@ handle_delete (UDisksPartition       *partition,
                                          UDISKS_OBJECT (object),
                                          "partition-delete",
                                          caller_uid,
-                                         FALSE,
                                          NULL);
 
   if (job == NULL)
@@ -1143,17 +829,12 @@ handle_delete (UDisksPartition       *partition,
       goto out;
     }
   /* this is sometimes needed because parted(8) does not generate the uevent itself */
-  udisks_linux_block_object_trigger_uevent_sync (UDISKS_LINUX_BLOCK_OBJECT (partition_table_object),
-                                                 UDISKS_DEFAULT_WAIT_TIMEOUT);
+  udisks_linux_block_object_trigger_uevent (UDISKS_LINUX_BLOCK_OBJECT (partition_table_object));
 
   udisks_partition_complete_delete (partition, invocation);
   udisks_simple_job_complete (UDISKS_SIMPLE_JOB (job), TRUE, NULL);
 
  out:
-  if (object != NULL)
-    udisks_linux_block_object_release_cleanup_lock (UDISKS_LINUX_BLOCK_OBJECT (object));
-  if (state != NULL)
-    udisks_state_check (state);
   g_free (device_name);
   g_free (partition_name);
   g_clear_error (&error);
@@ -1173,8 +854,6 @@ partition_iface_init (UDisksPartitionIface *iface)
 {
   iface->handle_set_flags = handle_set_flags;
   iface->handle_set_name  = handle_set_name;
-  iface->handle_set_uuid  = handle_set_uuid;
   iface->handle_set_type  = handle_set_type;
-  iface->handle_resize    = handle_resize;
   iface->handle_delete    = handle_delete;
 }
