@@ -117,107 +117,16 @@ void
 udisks_linux_partition_table_update (UDisksLinuxPartitionTable  *table,
                                      UDisksLinuxBlockObject     *object)
 {
-  UDisksLinuxDevice *device = NULL;
-  UDisksDaemon *daemon = NULL;
-  guint num_parts = 0;
-  const gchar **partition_object_paths = NULL;
-  const gchar *part_type = NULL;
-  GList *partition_objects = NULL;
-  GList *object_p = NULL;
-  guint i = 0;
-  const gchar *device_file;
-  BDPartDiskSpec *spec;
-  GError *error = NULL;
+  const gchar *type = NULL;
+  UDisksLinuxDevice *device = NULL;;
 
-  /* update list of partitions */
-  daemon = udisks_linux_block_object_get_daemon (UDISKS_LINUX_BLOCK_OBJECT (object));
-
-  partition_objects = udisks_linux_partition_table_get_partitions (daemon, UDISKS_PARTITION_TABLE (table), &num_parts);
-
-  partition_object_paths = g_new0 (const gchar *, num_parts + 1);
-  for (i = 0, object_p = partition_objects; object_p != NULL; object_p = object_p->next, i++)
-    {
-      partition_object_paths[i] = g_dbus_object_get_object_path (g_dbus_interface_get_object (G_DBUS_INTERFACE (object_p->data)));
-    }
-
-  udisks_partition_table_set_partitions (UDISKS_PARTITION_TABLE (table),
-                                         partition_object_paths);
-
-  /* update partition table type */
   device = udisks_linux_block_object_get_device (object);
-  if (device)
-    {
-      part_type = g_udev_device_get_property (device->udev_device, "ID_PART_TABLE_TYPE");
-      if (!part_type && num_parts > 0)
-        {
-          /* probe the device in case no cached udev property is available */
-          device_file = g_udev_device_get_device_file (device->udev_device);
-          if (device_file)
-            {
-              spec = bd_part_get_disk_spec (device_file, &error);
-              if (spec)
-                {
-                  part_type = bd_part_get_part_table_type_str (spec->table_type, NULL);
-                  bd_part_disk_spec_free (spec);
-                }
-              else
-                {
-                  udisks_warning ("Partitions found on device '%s' but couldn't read partition table signature: %s",
-                                  device_file, error->message);
-                  g_clear_error (&error);
-                }
-            }
-        }
-    }
-  udisks_partition_table_set_type_ (UDISKS_PARTITION_TABLE (table), part_type);
+  if (device != NULL)
+    type = g_udev_device_get_property (device->udev_device, "ID_PART_TABLE_TYPE");
 
-  g_dbus_interface_skeleton_flush (G_DBUS_INTERFACE_SKELETON (table));
+  udisks_partition_table_set_type_ (UDISKS_PARTITION_TABLE (table), type);
 
-  g_free (partition_object_paths);
   g_clear_object (&device);
-  g_list_free_full (partition_objects, g_object_unref);
-}
-
-/* ---------------------------------------------------------------------------------------------------- */
-
-GList *
-udisks_linux_partition_table_get_partitions (UDisksDaemon         *daemon,
-                                             UDisksPartitionTable *table,
-                                             guint                *num_partitions)
-{
-  GList *ret = NULL;
-  GDBusObject *table_object;
-  const gchar *table_object_path;
-  GList *l, *object_proxies = NULL;
-  *num_partitions = 0;
-
-  table_object = g_dbus_interface_get_object (G_DBUS_INTERFACE (table));
-  if (table_object == NULL)
-    goto out;
-  table_object_path = g_dbus_object_get_object_path (table_object);
-
-  object_proxies = udisks_daemon_get_objects (daemon);
-  for (l = object_proxies; l != NULL; l = l->next)
-    {
-      UDisksObject *object = UDISKS_OBJECT (l->data);
-      UDisksPartition *partition;
-
-      partition = udisks_object_get_partition (object);
-      if (partition == NULL)
-        continue;
-
-      if (g_strcmp0 (udisks_partition_get_table (partition), table_object_path) == 0)
-        {
-          ret = g_list_prepend (ret, g_object_ref (partition));
-          (*num_partitions)++;
-        }
-
-      g_object_unref (partition);
-    }
-  ret = g_list_reverse (ret);
- out:
-  g_list_free_full (object_proxies, g_object_unref);
-  return ret;
 }
 
 /* ---------------------------------------------------------------------------------------------------- */
@@ -292,24 +201,23 @@ udisks_linux_partition_table_handle_create_partition (UDisksPartitionTable   *ta
   BDPartSpec *part_spec = NULL;
   BDPartSpec *overlapping_part = NULL;
   BDPartTypeReq part_type = 0;
-  gchar *table_type = NULL;
+  const gchar *table_type;
   uid_t caller_uid;
+  gid_t caller_gid;
   GError *error = NULL;
   UDisksBaseJob *job = NULL;
-  const gchar *partition_type = NULL;
-  const gchar *partition_uuid = NULL;
+  gchar *partition_type = NULL;
 
   object = udisks_daemon_util_dup_object (table, &error);
   if (object == NULL)
     {
-      g_dbus_method_invocation_return_gerror (invocation, error);
+      g_dbus_method_invocation_take_error (invocation, error);
       goto out;
     }
 
   daemon = udisks_linux_block_object_get_daemon (UDISKS_LINUX_BLOCK_OBJECT (object));
 
-  g_variant_lookup (options, "partition-type", "&s", &partition_type);
-  g_variant_lookup (options, "partition-uuid", "&s", &partition_uuid);
+  g_variant_lookup (options, "partition-type", "s", &partition_type);
 
   block = udisks_object_get_block (object);
   if (block == NULL)
@@ -319,13 +227,17 @@ udisks_linux_partition_table_handle_create_partition (UDisksPartitionTable   *ta
       goto out;
     }
 
+  error = NULL;
   if (!udisks_daemon_util_get_caller_uid_sync (daemon,
                                                invocation,
                                                NULL /* GCancellable */,
                                                &caller_uid,
+                                               &caller_gid,
+                                               NULL,
                                                &error))
     {
       g_dbus_method_invocation_return_gerror (invocation, error);
+      g_clear_error (&error);
       goto out;
     }
 
@@ -359,7 +271,7 @@ udisks_linux_partition_table_handle_create_partition (UDisksPartitionTable   *ta
 
   device_name = g_strdup (udisks_block_get_device (block));
 
-  table_type = udisks_partition_table_dup_type_ (table);
+  table_type = udisks_partition_table_get_type_ (table);
   wait_data = g_new0 (WaitForPartitionData, 1);
   if (g_strcmp0 (table_type, "dos") == 0)
     {
@@ -422,7 +334,6 @@ udisks_linux_partition_table_handle_create_partition (UDisksPartitionTable   *ta
                                          UDISKS_OBJECT (object),
                                          "partition-create",
                                          caller_uid,
-                                         FALSE,
                                          NULL);
 
   if (job == NULL)
@@ -444,12 +355,12 @@ udisks_linux_partition_table_handle_create_partition (UDisksPartitionTable   *ta
   overlapping_part = bd_part_get_part_by_pos (device_name, offset, &error);
   if (overlapping_part != NULL && ! (overlapping_part->type & BD_PART_TYPE_FREESPACE))
     {
-      /* extended partition or metadata of the extended partition */
+      // extended partition or metadata of the extended partition
       if (overlapping_part->type & BD_PART_TYPE_EXTENDED || overlapping_part->type & (BD_PART_TYPE_LOGICAL | BD_PART_TYPE_METADATA))
         {
           if (overlapping_part->start == offset)
             {
-              /* just add 1 byte, libblockdev will adjust it */
+              // just add 1 byte, libblockdev will adjust it
               offset += 1;
               udisks_warning ("Requested start of the logical partition overlaps "
                               "with extended partition metadata. Start of the "
@@ -458,12 +369,11 @@ udisks_linux_partition_table_handle_create_partition (UDisksPartitionTable   *ta
         }
       else
         {
-          /* overlapping partition is not a free space nor an extended part -> error */
+          // overlapping partition is not a free space nor an extended part -> error
           g_dbus_method_invocation_return_error (invocation, UDISKS_ERROR, UDISKS_ERROR_FAILED,
                                                  "Requested start for the new partition %"G_GUINT64_FORMAT" "
                                                  "overlaps with existing partition %s.",
                                                   offset, overlapping_part->path);
-          udisks_simple_job_complete (UDISKS_SIMPLE_JOB (job), FALSE, NULL);
           goto out;
         }
     }
@@ -484,28 +394,15 @@ udisks_linux_partition_table_handle_create_partition (UDisksPartitionTable   *ta
       goto out;
     }
 
-  /* set name and UUID if given */
-  if (g_strcmp0 (table_type, "gpt") == 0)
+  /* set name if given */
+  if (g_strcmp0 (table_type, "gpt") == 0 && strlen (name) > 0)
     {
-      if (strlen (name) > 0)
+      if (!bd_part_set_part_name (device_name, part_spec->path, name, &error))
         {
-          if (!bd_part_set_part_name (device_name, part_spec->path, name, &error))
-            {
-              g_prefix_error (&error, "Error setting name for newly created partition: ");
-              g_dbus_method_invocation_return_gerror (invocation, error);
-              udisks_simple_job_complete (UDISKS_SIMPLE_JOB (job), FALSE, error->message);
-              goto out;
-            }
-        }
-      else if (partition_uuid)
-        {
-          if (!bd_part_set_part_uuid (device_name, part_spec->path, partition_uuid, &error))
-            {
-              g_prefix_error (&error, "Error setting partition UUID for newly created partition: ");
-              g_dbus_method_invocation_return_gerror (invocation, error);
-              udisks_simple_job_complete (UDISKS_SIMPLE_JOB (job), FALSE, error->message);
-              goto out;
-            }
+          g_prefix_error (&error, "Error setting name for newly created partition: ");
+          g_dbus_method_invocation_take_error (invocation, error);
+          udisks_simple_job_complete (UDISKS_SIMPLE_JOB (job), FALSE, error->message);
+          goto out;
         }
     }
 
@@ -522,49 +419,29 @@ udisks_linux_partition_table_handle_create_partition (UDisksPartitionTable   *ta
       if (!ret)
         {
           g_prefix_error (&error, "Error setting type for newly created partition: ");
-          g_dbus_method_invocation_return_gerror (invocation, error);
+          g_dbus_method_invocation_take_error (invocation, error);
           udisks_simple_job_complete (UDISKS_SIMPLE_JOB (job), FALSE, error->message);
           goto out;
         }
     }
 
-  /* wipe the newly created partition if wanted */
-  if (part_spec->type != BD_PART_TYPE_EXTENDED)
-    {
-      if (!bd_fs_wipe (part_spec->path, TRUE, FALSE, &error))
-        {
-          if (g_error_matches (error, BD_FS_ERROR, BD_FS_ERROR_NOFS))
-            g_clear_error (&error);
-          else
-            {
-              g_dbus_method_invocation_return_error (invocation,
-                                                     UDISKS_ERROR,
-                                                     UDISKS_ERROR_FAILED,
-                                                     "Error wiping newly created partition %s: %s",
-                                                     part_spec->path,
-                                                     error->message);
-              udisks_simple_job_complete (UDISKS_SIMPLE_JOB (job), FALSE, error->message);
-              goto out;
-            }
-        }
-    }
-
   wait_data->ignore_container = (part_spec->type == BD_PART_TYPE_LOGICAL);
   wait_data->pos_to_wait_for = part_spec->start + (part_spec->size / 2L);
 
   /* sit and wait for the partition to show up */
   g_warn_if_fail (wait_data->pos_to_wait_for > 0);
   wait_data->partition_table_object = object;
+  error = NULL;
   partition_object = udisks_daemon_wait_for_object_sync (daemon,
                                                          wait_for_partition,
                                                          wait_data,
                                                          NULL,
-                                                         UDISKS_DEFAULT_WAIT_TIMEOUT,
+                                                         30,
                                                          &error);
   if (partition_object == NULL)
     {
       g_prefix_error (&error, "Error waiting for partition to appear: ");
-      g_dbus_method_invocation_return_gerror (invocation, error);
+      g_dbus_method_invocation_take_error (invocation, error);
       udisks_simple_job_complete (UDISKS_SIMPLE_JOB (job), FALSE, error->message);
       goto out;
     }
@@ -578,18 +455,33 @@ udisks_linux_partition_table_handle_create_partition (UDisksPartitionTable   *ta
       goto out;
     }
 
-  /* Trigger uevent on the disk -- we sometimes get add-remove-add uevents for
-     the new partition without getting change event for the disks after the
-     last add event and this breaks the "Partitions" property on the
-     "PartitionTable" interface. */
-  udisks_linux_block_object_trigger_uevent_sync (UDISKS_LINUX_BLOCK_OBJECT (object),
-                                                 UDISKS_DEFAULT_WAIT_TIMEOUT);
+  /* wipe the newly created partition if wanted */
+  if (part_spec->type != BD_PART_TYPE_EXTENDED)
+    {
+      if (!bd_fs_wipe (part_spec->path, TRUE, &error))
+        {
+          if (g_error_matches (error, BD_FS_ERROR, BD_FS_ERROR_NOFS))
+            g_clear_error (&error);
+          else
+            {
+              g_dbus_method_invocation_return_error (invocation,
+                                                     UDISKS_ERROR,
+                                                     UDISKS_ERROR_FAILED,
+                                                     "Error wiping newly created partition %s: %s",
+                                                     udisks_block_get_device (partition_block),
+                                                     error->message);
+              udisks_simple_job_complete (UDISKS_SIMPLE_JOB (job), FALSE, error->message);
+              g_clear_object (&partition_object);
+              goto out;
+            }
+        }
+    }
 
   udisks_simple_job_complete (UDISKS_SIMPLE_JOB (job), TRUE, NULL);
 
  out:
-  g_free (table_type);
   g_free (wait_data);
+  g_free (overlapping_part);
   g_clear_error (&error);
   g_clear_object (&partition_block);
   g_free (device_name);
@@ -597,8 +489,6 @@ udisks_linux_partition_table_handle_create_partition (UDisksPartitionTable   *ta
   g_clear_object (&block);
   if (part_spec)
     bd_part_spec_free (part_spec);
-  if (overlapping_part)
-    bd_part_spec_free (overlapping_part);
   return partition_object;
 }
 
